@@ -25,8 +25,6 @@ import (
 	"io/ioutil"
 	"net/http"
 
-	"github.com/manyminds/api2go/jsonapi"
-
 	"go.k6.io/k6/api/common"
 )
 
@@ -42,11 +40,15 @@ type SetupData struct {
 }
 
 // GetName is a dummy method so we can satisfy the jsonapi.EntityNamer interface
+// Deprecated: use a constant value instead
+// This method will be removed with the one of the PRs of (https://github.com/grafana/k6/issues/911)
 func (sd SetupData) GetName() string {
 	return "setupData"
 }
 
 // GetID is a dummy method so we can satisfy the jsonapi.MarshalIdentifier interface
+// Deprecated: use a constant value instead
+// This method will be removed with the one of the PRs of (https://github.com/grafana/k6/issues/911)
 func (sd SetupData) GetID() string {
 	return "default"
 }
@@ -57,9 +59,9 @@ func handleSetupDataOutput(rw http.ResponseWriter, setupData json.RawMessage) {
 	var data []byte
 
 	if setupData == nil {
-		data, err = jsonapi.Marshal(NullSetupData{Data: nil})
+		data, err = json.Marshal(newSetUpJSONAPI(NullSetupData{Data: nil}))
 	} else {
-		data, err = jsonapi.Marshal(SetupData{setupData})
+		data, err = json.Marshal(newSetUpJSONAPI(SetupData{setupData}))
 	}
 	if err != nil {
 		apiError(rw, "Encoding error", err.Error(), http.StatusInternalServerError)
