@@ -52,6 +52,7 @@ func TestConfigApply(t *testing.T) {
 		WebAppURL:                       null.NewString("foo", true),
 		NoCompress:                      null.NewBool(true, true),
 		StopOnError:                     null.NewBool(true, true),
+		Timeout:                         types.NewNullDuration(5*time.Second, true),
 		MaxMetricSamplesPerPackage:      null.NewInt(2, true),
 		MetricPushInterval:              types.NewNullDuration(1*time.Second, true),
 		MetricPushConcurrency:           null.NewInt(3, true),
@@ -84,6 +85,7 @@ func TestGetConsolidatedConfig(t *testing.T) { //nolint:paralleltest
 	require.Equal(t, config.Token.String, "ext")
 
 	require.NoError(t, os.Setenv("K6_CLOUD_TOKEN", "envvalue")) // TODO drop when we don't use envconfig
+	defer os.Unsetenv("K6_CLOUD_TOKEN")                         //nolint:errcheck
 	config, err = GetConsolidatedConfig(json.RawMessage(`{"token":"jsonraw"}`), nil, "",
 		map[string]json.RawMessage{"loadimpact": json.RawMessage(`{"token":"ext"}`)})
 	require.NoError(t, err)
