@@ -45,7 +45,7 @@ import (
 	"go.k6.io/k6/errext/exitcodes"
 	"go.k6.io/k6/lib"
 	"go.k6.io/k6/lib/consts"
-	"go.k6.io/k6/loader"
+	"go.k6.io/k6/lib/metrics"
 	"go.k6.io/k6/ui/pb"
 )
 
@@ -89,14 +89,8 @@ This will execute the test on the k6 cloud service. Use "k6 login cloud" to auth
 			printBar(progressBar)
 
 			// Runner
-			pwd, err := os.Getwd()
-			if err != nil {
-				return err
-			}
-
 			filename := args[0]
-			filesystems := loader.CreateFilesystems()
-			src, err := loader.ReadSource(logger, filename, pwd, filesystems, os.Stdin)
+			src, filesystems, err := readSource(filename, logger)
 			if err != nil {
 				return err
 			}
@@ -108,7 +102,9 @@ This will execute the test on the k6 cloud service. Use "k6 login cloud" to auth
 			}
 
 			modifyAndPrintBar(progressBar, pb.WithConstProgress(0, "Getting script options"))
-			r, err := newRunner(logger, src, runType, filesystems, runtimeOptions)
+			registry := metrics.NewRegistry()
+			builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
+			r, err := newRunner(logger, src, runType, filesystems, runtimeOptions, builtinMetrics, registry)
 			if err != nil {
 				return err
 			}
@@ -118,7 +114,7 @@ This will execute the test on the k6 cloud service. Use "k6 login cloud" to auth
 			if err != nil {
 				return err
 			}
-			conf, err := getConsolidatedConfig(afero.NewOsFs(), Config{Options: cliOpts}, r)
+			conf, err := getConsolidatedConfig(afero.NewOsFs(), Config{Options: cliOpts}, r.GetOptions())
 			if err != nil {
 				return err
 			}
@@ -196,7 +192,8 @@ This will execute the test on the k6 cloud service. Use "k6 login cloud" to auth
 
 			// Start cloud test run
 			modifyAndPrintBar(progressBar, pb.WithConstProgress(0, "Validating script options"))
-			client := cloudapi.NewClient(logger, cloudConfig.Token.String, cloudConfig.Host.String, consts.Version)
+			client := cloudapi.NewClient(
+				logger, cloudConfig.Token.String, cloudConfig.Host.String, consts.Version, cloudConfig.Timeout.TimeDuration())
 			if err = client.ValidateOptions(arc.Options); err != nil {
 				return err
 			}
