@@ -21,7 +21,6 @@
 package cmd
 
 import (
-	"archive/tar"
 	"bytes"
 	"context"
 	"encoding/json"
@@ -47,8 +46,10 @@ import (
 	"go.k6.io/k6/errext"
 	"go.k6.io/k6/errext/exitcodes"
 	"go.k6.io/k6/js"
+	"go.k6.io/k6/js/common"
 	"go.k6.io/k6/lib"
 	"go.k6.io/k6/lib/consts"
+	"go.k6.io/k6/lib/metrics"
 	"go.k6.io/k6/loader"
 	"go.k6.io/k6/ui/pb"
 )
@@ -98,13 +99,7 @@ a commandline interface for interacting with it.`,
 			logger.Debug("Initializing the runner...")
 
 			// Create the Runner.
-			pwd, err := os.Getwd()
-			if err != nil {
-				return err
-			}
-			filename := args[0]
-			filesystems := loader.CreateFilesystems()
-			src, err := loader.ReadSource(logger, filename, pwd, filesystems, os.Stdin)
+			src, filesystems, err := readSource(args[0], logger)
 			if err != nil {
 				return err
 			}
@@ -115,9 +110,11 @@ a commandline interface for interacting with it.`,
 				return err
 			}
 
-			initRunner, err := newRunner(logger, src, runType, filesystems, runtimeOptions)
+			registry := metrics.NewRegistry()
+			builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
+			initRunner, err := newRunner(logger, src, runType, filesystems, runtimeOptions, builtinMetrics, registry)
 			if err != nil {
-				return err
+				return common.UnwrapGojaInterruptedError(err)
 			}
 
 			logger.Debug("Getting the script options...")
@@ -126,7 +123,7 @@ a commandline interface for interacting with it.`,
 			if err != nil {
 				return err
 			}
-			conf, err := getConsolidatedConfig(afero.NewOsFs(), cliConf, initRunner)
+			conf, err := getConsolidatedConfig(afero.NewOsFs(), cliConf, initRunner.GetOptions())
 			if err != nil {
 				return err
 			}
@@ -192,7 +189,7 @@ a commandline interface for interacting with it.`,
 
 			// Create the engine.
 			initBar.Modify(pb.WithConstProgress(0, "Init engine"))
-			engine, err := core.NewEngine(execScheduler, conf.Options, runtimeOptions, outputs, logger)
+			engine, err := core.NewEngine(execScheduler, conf.Options, runtimeOptions, outputs, logger, builtinMetrics)
 			if err != nil {
 				return err
 			}
@@ -223,7 +220,7 @@ a commandline interface for interacting with it.`,
 			defer engine.StopOutputs()
 
 			printExecutionDescription(
-				"local", filename, "", conf, execScheduler.GetState().ExecutionTuple,
+				"local", args[0], "", conf, execScheduler.GetState().ExecutionTuple,
 				executionPlan, outputs, noColor || !stdoutTTY)
 
 			// Trap Interrupts, SIGINTs and SIGTERMs.
@@ -247,6 +244,7 @@ a commandline interface for interacting with it.`,
 			initBar.Modify(pb.WithConstProgress(0, "Init VUs..."))
 			engineRun, engineWait, err := engine.Init(globalCtx, runCtx)
 			if err != nil {
+				err = common.UnwrapGojaInterruptedError(err)
 				// Add a generic engine exit code if we don't have a more specific one
 				return errext.WithExitCodeIfNone(err, exitcodes.GenericEngine)
 			}
@@ -270,8 +268,18 @@ a commandline interface for interacting with it.`,
 
 			// Start the test run
 			initBar.Modify(pb.WithConstProgress(0, "Starting test..."))
-			if err := engineRun(); err != nil {
-				return errext.WithExitCodeIfNone(err, exitcodes.GenericEngine)
+			var interrupt error
+			err = engineRun()
+			if err != nil {
+				err = common.UnwrapGojaInterruptedError(err)
+				if common.IsInterruptError(err) {
+					// Don't return here since we need to work with --linger,
+					// show the end-of-test summary and exit cleanly.
+					interrupt = err
+				}
+				if !conf.Linger.Bool && interrupt == nil {
+					return errext.WithExitCodeIfNone(err, exitcodes.GenericEngine)
+				}
 			}
 			runCancel()
 			logger.Debug("Engine run terminated cleanly")
@@ -320,6 +328,9 @@ a commandline interface for interacting with it.`,
 			logger.Debug("Waiting for engine processes to finish...")
 			engineWait()
 			logger.Debug("Everything has finished, exiting k6!")
+			if interrupt != nil {
+				return interrupt
+			}
 			if engine.IsTainted() {
 				return errext.WithExitCodeIfNone(errors.New("some thresholds have failed"), exitcodes.ThresholdsHaveFailed)
 			}
@@ -386,12 +397,13 @@ func runCmdFlagSet() *pflag.FlagSet {
 // Creates a new runner.
 func newRunner(
 	logger *logrus.Logger, src *loader.SourceData, typ string, filesystems map[string]afero.Fs, rtOpts lib.RuntimeOptions,
+	builtinMetrics *metrics.BuiltinMetrics, registry *metrics.Registry,
 ) (runner lib.Runner, err error) {
 	switch typ {
 	case "":
-		runner, err = newRunner(logger, src, detectType(src.Data), filesystems, rtOpts)
+		runner, err = newRunner(logger, src, detectType(src.Data), filesystems, rtOpts, builtinMetrics, registry)
 	case typeJS:
-		runner, err = js.New(logger, src, filesystems, rtOpts)
+		runner, err = js.New(logger, src, filesystems, rtOpts, builtinMetrics, registry)
 	case typeArchive:
 		var arc *lib.Archive
 		arc, err = lib.ReadArchive(bytes.NewReader(src.Data))
@@ -400,7 +412,7 @@ func newRunner(
 		}
 		switch arc.Type {
 		case typeJS:
-			runner, err = js.NewFromArchive(logger, arc, rtOpts)
+			runner, err = js.NewFromArchive(logger, arc, rtOpts, builtinMetrics, registry)
 		default:
 			return nil, fmt.Errorf("archive requests unsupported runner: %s", arc.Type)
 		}
@@ -411,13 +423,6 @@ func newRunner(
 	return runner, err
 }
 
-func detectType(data []byte) string {
-	if _, err := tar.NewReader(bytes.NewReader(data)).Next(); err == nil {
-		return typeArchive
-	}
-	return typeJS
-}
-
 func handleSummaryResult(fs afero.Fs, stdOut, stdErr io.Writer, result map[string]io.Reader) error {
 	var errs []error
 
