@@ -32,6 +32,7 @@ import (
 	"gopkg.in/guregu/null.v3"
 
 	"go.k6.io/k6/lib"
+	"go.k6.io/k6/lib/metrics"
 	"go.k6.io/k6/lib/testutils"
 	"go.k6.io/k6/loader"
 )
@@ -319,12 +320,16 @@ func testRuntimeOptionsCase(t *testing.T, tc runtimeOptionsTestCase) {
 
 	fs := afero.NewMemMapFs()
 	require.NoError(t, afero.WriteFile(fs, "/script.js", jsCode.Bytes(), 0o644))
+	registry := metrics.NewRegistry()
+	builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
 	runner, err := newRunner(
 		testutils.NewLogger(t),
 		&loader.SourceData{Data: jsCode.Bytes(), URL: &url.URL{Path: "/script.js", Scheme: "file"}},
 		typeJS,
 		map[string]afero.Fs{"file": fs},
 		rtOpts,
+		builtinMetrics,
+		registry,
 	)
 	require.NoError(t, err)
 
@@ -342,6 +347,8 @@ func testRuntimeOptionsCase(t *testing.T, tc runtimeOptionsTestCase) {
 			typeArchive,
 			nil,
 			rtOpts,
+			builtinMetrics,
+			registry,
 		)
 	}
 
