@@ -37,6 +37,7 @@ import (
 
 	"go.k6.io/k6/js/common"
 	"go.k6.io/k6/lib"
+	"go.k6.io/k6/lib/metrics"
 	"go.k6.io/k6/lib/testutils"
 	"go.k6.io/k6/loader"
 	"go.k6.io/k6/stats"
@@ -47,7 +48,10 @@ func TestConsoleContext(t *testing.T) {
 	rt := goja.New()
 	rt.SetFieldNameMapper(common.FieldNameMapper{})
 
-	ctxPtr := new(context.Context)
+	ctx, cancel := context.WithCancel(context.Background())
+	defer cancel()
+	ctxPtr := &ctx
+
 	logger, hook := logtest.NewNullLogger()
 	rt.Set("console", common.Bind(rt, &console{logger}, ctxPtr))
 
@@ -57,7 +61,7 @@ func TestConsoleContext(t *testing.T) {
 		assert.Equal(t, "a", entry.Message)
 	}
 
-	ctx, cancel := context.WithCancel(context.Background())
+	ctx, cancel = context.WithCancel(context.Background())
 	*ctxPtr = ctx
 	_, err = rt.RunString(`console.log("b")`)
 	assert.NoError(t, err)
@@ -89,6 +93,8 @@ func getSimpleRunner(tb testing.TB, filename, data string, opts ...interface{})
 			logger = opt
 		}
 	}
+	registry := metrics.NewRegistry()
+	builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
 	return New(
 		logger,
 		&loader.SourceData{
@@ -97,6 +103,8 @@ func getSimpleRunner(tb testing.TB, filename, data string, opts ...interface{})
 		},
 		map[string]afero.Fs{"file": fs, "https": afero.NewMemMapFs()},
 		rtOpts,
+		builtinMetrics,
+		registry,
 	)
 }
 
