@@ -48,6 +48,7 @@ import (
 	"go.k6.io/k6/js/modules/k6/metrics"
 	"go.k6.io/k6/js/modules/k6/ws"
 	"go.k6.io/k6/lib"
+	"go.k6.io/k6/lib/fsext"
 	"go.k6.io/k6/loader"
 )
 
@@ -151,24 +152,25 @@ func (i *InitContext) Require(arg string) goja.Value {
 	}
 }
 
-type moduleInstanceCoreImpl struct {
+// TODO this likely should just be part of the initialized VU or at least to take stuff directly from it.
+type moduleVUImpl struct {
 	ctxPtr *context.Context
 	// we can technically put lib.State here as well as anything else
 }
 
-func (m *moduleInstanceCoreImpl) GetContext() context.Context {
+func (m *moduleVUImpl) Context() context.Context {
 	return *m.ctxPtr
 }
 
-func (m *moduleInstanceCoreImpl) GetInitEnv() *common.InitEnvironment {
+func (m *moduleVUImpl) InitEnv() *common.InitEnvironment {
 	return common.GetInitEnv(*m.ctxPtr) // TODO thread it correctly instead
 }
 
-func (m *moduleInstanceCoreImpl) GetState() *lib.State {
+func (m *moduleVUImpl) State() *lib.State {
 	return lib.GetState(*m.ctxPtr) // TODO thread it correctly instead
 }
 
-func (m *moduleInstanceCoreImpl) GetRuntime() *goja.Runtime {
+func (m *moduleVUImpl) Runtime() *goja.Runtime {
 	return common.GetRuntime(*m.ctxPtr) // TODO thread it correctly instead
 }
 
@@ -200,9 +202,9 @@ func (i *InitContext) requireModule(name string) (goja.Value, error) {
 	if !ok {
 		return nil, fmt.Errorf("unknown module: %s", name)
 	}
-	if modV2, ok := mod.(modules.IsModuleV2); ok {
-		instance := modV2.NewModuleInstance(&moduleInstanceCoreImpl{ctxPtr: i.ctxPtr})
-		return i.runtime.ToValue(toESModuleExports(instance.GetExports())), nil
+	if m, ok := mod.(modules.Module); ok {
+		instance := m.NewModuleInstance(&moduleVUImpl{ctxPtr: i.ctxPtr})
+		return i.runtime.ToValue(toESModuleExports(instance.Exports())), nil
 	}
 	if perInstance, ok := mod.(modules.HasModuleInstancePerVU); ok {
 		mod = perInstance.NewModuleInstancePerVU()
@@ -269,8 +271,7 @@ func (i *InitContext) requireFile(name string) (goja.Value, error) {
 }
 
 func (i *InitContext) compileImport(src, filename string) (*goja.Program, error) {
-	pgm, _, err := i.compiler.Compile(src, filename,
-		"(function(module, exports){\n", "\n})\n", true, i.compatibilityMode)
+	pgm, _, err := i.compiler.Compile(src, filename, false)
 	return pgm, err
 }
 
@@ -298,13 +299,8 @@ func (i *InitContext) Open(ctx context.Context, filename string, args ...string)
 	if filename[0:1] != afero.FilePathSeparator {
 		filename = afero.FilePathSeparator + filename
 	}
-	// Workaround for https://github.com/spf13/afero/issues/201
-	if isDir, err := afero.IsDir(fs, filename); err != nil {
-		return nil, err
-	} else if isDir {
-		return nil, fmt.Errorf("open() can't be used with directories, path: %q", filename)
-	}
-	data, err := afero.ReadFile(fs, filename)
+
+	data, err := readFile(fs, filename)
 	if err != nil {
 		return nil, err
 	}
@@ -316,6 +312,40 @@ func (i *InitContext) Open(ctx context.Context, filename string, args ...string)
 	return i.runtime.ToValue(string(data)), nil
 }
 
+func readFile(fileSystem afero.Fs, filename string) (data []byte, err error) {
+	defer func() {
+		if errors.Is(err, fsext.ErrPathNeverRequestedBefore) {
+			// loading different files per VU is not supported, so all files should are going
+			// to be used inside the scenario should be opened during the init step (without any conditions)
+			err = fmt.Errorf(
+				"open() can't be used with files that weren't previously opened during initialization (__VU==0), path: %q",
+				filename,
+			)
+		}
+	}()
+
+	// Workaround for https://github.com/spf13/afero/issues/201
+	if isDir, err := afero.IsDir(fileSystem, filename); err != nil {
+		return nil, err
+	} else if isDir {
+		return nil, fmt.Errorf("open() can't be used with directories, path: %q", filename)
+	}
+
+	return afero.ReadFile(fileSystem, filename)
+}
+
+// allowOnlyOpenedFiles enables seen only files
+func (i *InitContext) allowOnlyOpenedFiles() {
+	fs := i.filesystems["file"]
+
+	alreadyOpenedFS, ok := fs.(fsext.OnlyCachedEnabler)
+	if !ok {
+		return
+	}
+
+	alreadyOpenedFS.AllowOnlyCached()
+}
+
 func getInternalJSModules() map[string]interface{} {
 	return map[string]interface{}{
 		"k6":             k6.New(),
