@@ -22,7 +22,6 @@ package http
 
 import (
 	"bytes"
-	"context"
 	"errors"
 	"fmt"
 	"mime/multipart"
@@ -37,7 +36,6 @@ import (
 	"gopkg.in/guregu/null.v3"
 
 	"go.k6.io/k6/js/common"
-	"go.k6.io/k6/lib"
 	"go.k6.io/k6/lib/netext/httpext"
 	"go.k6.io/k6/lib/types"
 )
@@ -48,49 +46,16 @@ var ErrHTTPForbiddenInInitContext = common.NewInitContextError("Making http requ
 // ErrBatchForbiddenInInitContext is used when batch was made in the init context
 var ErrBatchForbiddenInInitContext = common.NewInitContextError("Using batch in the init context is not supported")
 
-// Get makes an HTTP GET request and returns a corresponding response by taking goja.Values as arguments
-func (h *HTTP) Get(ctx context.Context, url goja.Value, args ...goja.Value) (*Response, error) {
-	// The body argument is always undefined for GETs and HEADs.
-	args = append([]goja.Value{goja.Undefined()}, args...)
-	return h.Request(ctx, HTTP_METHOD_GET, url, args...)
-}
-
-// Head makes an HTTP HEAD request and returns a corresponding response by taking goja.Values as arguments
-func (h *HTTP) Head(ctx context.Context, url goja.Value, args ...goja.Value) (*Response, error) {
-	// The body argument is always undefined for GETs and HEADs.
-	args = append([]goja.Value{goja.Undefined()}, args...)
-	return h.Request(ctx, HTTP_METHOD_HEAD, url, args...)
-}
-
-// Post makes an HTTP POST request and returns a corresponding response by taking goja.Values as arguments
-func (h *HTTP) Post(ctx context.Context, url goja.Value, args ...goja.Value) (*Response, error) {
-	return h.Request(ctx, HTTP_METHOD_POST, url, args...)
-}
-
-// Put makes an HTTP PUT request and returns a corresponding response by taking goja.Values as arguments
-func (h *HTTP) Put(ctx context.Context, url goja.Value, args ...goja.Value) (*Response, error) {
-	return h.Request(ctx, HTTP_METHOD_PUT, url, args...)
-}
-
-// Patch makes a patch request and returns a corresponding response by taking goja.Values as arguments
-func (h *HTTP) Patch(ctx context.Context, url goja.Value, args ...goja.Value) (*Response, error) {
-	return h.Request(ctx, HTTP_METHOD_PATCH, url, args...)
-}
-
-// Del makes an HTTP DELETE and returns a corresponding response by taking goja.Values as arguments
-func (h *HTTP) Del(ctx context.Context, url goja.Value, args ...goja.Value) (*Response, error) {
-	return h.Request(ctx, HTTP_METHOD_DELETE, url, args...)
-}
-
-// Options makes an HTTP OPTIONS request and returns a corresponding response by taking goja.Values as arguments
-func (h *HTTP) Options(ctx context.Context, url goja.Value, args ...goja.Value) (*Response, error) {
-	return h.Request(ctx, HTTP_METHOD_OPTIONS, url, args...)
+func (c *Client) getMethodClosure(method string) func(url goja.Value, args ...goja.Value) (*Response, error) {
+	return func(url goja.Value, args ...goja.Value) (*Response, error) {
+		return c.Request(method, url, args...)
+	}
 }
 
 // Request makes an http request of the provided `method` and returns a corresponding response by
 // taking goja.Values as arguments
-func (h *HTTP) Request(ctx context.Context, method string, url goja.Value, args ...goja.Value) (*Response, error) {
-	state := lib.GetState(ctx)
+func (c *Client) Request(method string, url goja.Value, args ...goja.Value) (*Response, error) {
+	state := c.moduleInstance.vu.State()
 	if state == nil {
 		return nil, ErrHTTPForbiddenInInitContext
 	}
@@ -105,36 +70,49 @@ func (h *HTTP) Request(ctx context.Context, method string, url goja.Value, args
 		params = args[1]
 	}
 
-	req, err := h.parseRequest(ctx, method, url, body, params)
+	req, err := c.parseRequest(method, url, body, params)
 	if err != nil {
 		if state.Options.Throw.Bool {
 			return nil, err
 		}
 		state.Logger.WithField("error", err).Warn("Request Failed")
-		r := httpext.NewResponse(ctx)
+		r := httpext.NewResponse()
 		r.Error = err.Error()
 		var k6e httpext.K6Error
 		if errors.As(err, &k6e) {
 			r.ErrorCode = int(k6e.Code)
 		}
-		return &Response{Response: r}, nil
+		return &Response{Response: r, client: c}, nil
 	}
 
-	resp, err := httpext.MakeRequest(ctx, req)
+	resp, err := httpext.MakeRequest(c.moduleInstance.vu.Context(), state, req)
 	if err != nil {
 		return nil, err
 	}
-	processResponse(ctx, resp, req.ResponseType)
-	return h.responseFromHttpext(resp), nil
+	c.processResponse(resp, req.ResponseType)
+	return c.responseFromHTTPext(resp), nil
 }
 
-//TODO break this function up
-//nolint: gocyclo
-func (h *HTTP) parseRequest(
-	ctx context.Context, method string, reqURL, body interface{}, params goja.Value,
+// processResponse stores the body as an ArrayBuffer if indicated by
+// respType. This is done here instead of in httpext.readResponseBody to avoid
+// a reverse dependency on js/common or goja.
+func (c *Client) processResponse(resp *httpext.Response, respType httpext.ResponseType) {
+	if respType == httpext.ResponseTypeBinary && resp.Body != nil {
+		resp.Body = c.moduleInstance.vu.Runtime().NewArrayBuffer(resp.Body.([]byte))
+	}
+}
+
+func (c *Client) responseFromHTTPext(resp *httpext.Response) *Response {
+	return &Response{Response: resp, client: c}
+}
+
+// TODO: break this function up
+//nolint: gocyclo, cyclop, funlen, gocognit
+func (c *Client) parseRequest(
+	method string, reqURL, body interface{}, params goja.Value,
 ) (*httpext.ParsedHTTPRequest, error) {
-	rt := common.GetRuntime(ctx)
-	state := lib.GetState(ctx)
+	rt := c.moduleInstance.vu.Runtime()
+	state := c.moduleInstance.vu.State()
 	if state == nil {
 		return nil, ErrHTTPForbiddenInInitContext
 	}
@@ -159,7 +137,7 @@ func (h *HTTP) parseRequest(
 		Redirects:        state.Options.MaxRedirects,
 		Cookies:          make(map[string]*httpext.HTTPRequestCookie),
 		Tags:             make(map[string]string),
-		ResponseCallback: h.responseCallback,
+		ResponseCallback: c.responseCallback,
 	}
 
 	if state.Options.DiscardResponseBodies.Bool {
@@ -328,8 +306,8 @@ func (h *HTTP) parseRequest(
 					continue
 				}
 				switch v := jarV.Export().(type) {
-				case *HTTPCookieJar:
-					result.ActiveJar = v.jar
+				case *CookieJar:
+					result.ActiveJar = v.Jar
 				}
 			case "compression":
 				algosString := strings.TrimSpace(params.Get(k).ToString().String())
@@ -397,60 +375,60 @@ func (h *HTTP) parseRequest(
 	return result, nil
 }
 
-func (h *HTTP) prepareBatchArray(
-	ctx context.Context, requests []interface{},
-) ([]httpext.BatchParsedHTTPRequest, []*Response, error) {
+func (c *Client) prepareBatchArray(requests []interface{}) (
+	[]httpext.BatchParsedHTTPRequest, []*Response, error,
+) {
 	reqCount := len(requests)
 	batchReqs := make([]httpext.BatchParsedHTTPRequest, reqCount)
 	results := make([]*Response, reqCount)
 
 	for i, req := range requests {
-		resp := httpext.NewResponse(ctx)
-		parsedReq, err := h.parseBatchRequest(ctx, i, req)
+		resp := httpext.NewResponse()
+		parsedReq, err := c.parseBatchRequest(i, req)
 		if err != nil {
 			resp.Error = err.Error()
 			var k6e httpext.K6Error
 			if errors.As(err, &k6e) {
 				resp.ErrorCode = int(k6e.Code)
 			}
-			results[i] = h.responseFromHttpext(resp)
+			results[i] = c.responseFromHTTPext(resp)
 			return batchReqs, results, err
 		}
 		batchReqs[i] = httpext.BatchParsedHTTPRequest{
 			ParsedHTTPRequest: parsedReq,
 			Response:          resp,
 		}
-		results[i] = h.responseFromHttpext(resp)
+		results[i] = c.responseFromHTTPext(resp)
 	}
 
 	return batchReqs, results, nil
 }
 
-func (h *HTTP) prepareBatchObject(
-	ctx context.Context, requests map[string]interface{},
-) ([]httpext.BatchParsedHTTPRequest, map[string]*Response, error) {
+func (c *Client) prepareBatchObject(requests map[string]interface{}) (
+	[]httpext.BatchParsedHTTPRequest, map[string]*Response, error,
+) {
 	reqCount := len(requests)
 	batchReqs := make([]httpext.BatchParsedHTTPRequest, reqCount)
 	results := make(map[string]*Response, reqCount)
 
 	i := 0
 	for key, req := range requests {
-		resp := httpext.NewResponse(ctx)
-		parsedReq, err := h.parseBatchRequest(ctx, key, req)
+		resp := httpext.NewResponse()
+		parsedReq, err := c.parseBatchRequest(key, req)
 		if err != nil {
 			resp.Error = err.Error()
 			var k6e httpext.K6Error
 			if errors.As(err, &k6e) {
 				resp.ErrorCode = int(k6e.Code)
 			}
-			results[key] = h.responseFromHttpext(resp)
+			results[key] = c.responseFromHTTPext(resp)
 			return batchReqs, results, err
 		}
 		batchReqs[i] = httpext.BatchParsedHTTPRequest{
 			ParsedHTTPRequest: parsedReq,
 			Response:          resp,
 		}
-		results[key] = h.responseFromHttpext(resp)
+		results[key] = c.responseFromHTTPext(resp)
 		i++
 	}
 
@@ -459,8 +437,8 @@ func (h *HTTP) prepareBatchObject(
 
 // Batch makes multiple simultaneous HTTP requests. The provideds reqsV should be an array of request
 // objects. Batch returns an array of responses and/or error
-func (h *HTTP) Batch(ctx context.Context, reqsV goja.Value) (interface{}, error) {
-	state := lib.GetState(ctx)
+func (c *Client) Batch(reqsV goja.Value) (interface{}, error) {
+	state := c.moduleInstance.vu.State()
 	if state == nil {
 		return nil, ErrBatchForbiddenInInitContext
 	}
@@ -473,9 +451,9 @@ func (h *HTTP) Batch(ctx context.Context, reqsV goja.Value) (interface{}, error)
 
 	switch v := reqsV.Export().(type) {
 	case []interface{}:
-		batchReqs, results, err = h.prepareBatchArray(ctx, v)
+		batchReqs, results, err = c.prepareBatchArray(v)
 	case map[string]interface{}:
-		batchReqs, results, err = h.prepareBatchObject(ctx, v)
+		batchReqs, results, err = c.prepareBatchObject(v)
 	default:
 		return nil, fmt.Errorf("invalid http.batch() argument type %T", v)
 	}
@@ -490,9 +468,9 @@ func (h *HTTP) Batch(ctx context.Context, reqsV goja.Value) (interface{}, error)
 
 	reqCount := len(batchReqs)
 	errs := httpext.MakeBatchRequests(
-		ctx, batchReqs, reqCount,
+		c.moduleInstance.vu.Context(), state, batchReqs, reqCount,
 		int(state.Options.Batch.Int64), int(state.Options.BatchPerHost.Int64),
-		processResponse,
+		c.processResponse,
 	)
 
 	for i := 0; i < reqCount; i++ {
@@ -503,15 +481,13 @@ func (h *HTTP) Batch(ctx context.Context, reqsV goja.Value) (interface{}, error)
 	return results, err
 }
 
-func (h *HTTP) parseBatchRequest(
-	ctx context.Context, key interface{}, val interface{},
-) (*httpext.ParsedHTTPRequest, error) {
+func (c *Client) parseBatchRequest(key interface{}, val interface{}) (*httpext.ParsedHTTPRequest, error) {
 	var (
-		method       = HTTP_METHOD_GET
+		method       = http.MethodGet
 		ok           bool
 		body, reqURL interface{}
 		params       goja.Value
-		rt           = common.GetRuntime(ctx)
+		rt           = c.moduleInstance.vu.Runtime()
 	)
 
 	switch data := val.(type) {
@@ -547,7 +523,7 @@ func (h *HTTP) parseBatchRequest(
 				return nil, fmt.Errorf("invalid method type '%#v'", newMethod)
 			}
 			method = strings.ToUpper(method)
-			if method == HTTP_METHOD_GET || method == HTTP_METHOD_HEAD {
+			if method == http.MethodGet || method == http.MethodHead {
 				body = nil
 			}
 		}
@@ -559,7 +535,7 @@ func (h *HTTP) parseBatchRequest(
 		reqURL = val
 	}
 
-	return h.parseRequest(ctx, method, reqURL, body, params)
+	return c.parseRequest(method, reqURL, body, params)
 }
 
 func requestContainsFile(data map[string]interface{}) bool {
