@@ -48,8 +48,7 @@ import (
 	"github.com/stretchr/testify/require"
 	"gopkg.in/guregu/null.v3"
 
-	"go.k6.io/k6/js/common"
-	"go.k6.io/k6/js/compiler"
+	"go.k6.io/k6/js/modulestest"
 	"go.k6.io/k6/lib"
 	"go.k6.io/k6/lib/metrics"
 	"go.k6.io/k6/lib/testutils"
@@ -57,30 +56,6 @@ import (
 	"go.k6.io/k6/stats"
 )
 
-// runES6String Runs an ES6 string in the given runtime. Use this rather than writing ES5 in tests.
-func runES6String(tb testing.TB, rt *goja.Runtime, src string) (goja.Value, error) {
-	var err error
-	c := compiler.New(testutils.NewLogger(tb)) // TODO drop it ? maybe we will drop babel and this will be less needed
-	src, _, err = c.Transform(src, "__string__")
-	if err != nil {
-		return goja.Undefined(), err
-	}
-
-	return rt.RunString(src)
-}
-
-func TestRunES6String(t *testing.T) {
-	t.Run("Valid", func(t *testing.T) {
-		_, err := runES6String(t, goja.New(), `let a = 1;`)
-		assert.NoError(t, err)
-	})
-	t.Run("Invalid", func(t *testing.T) {
-		_, err := runES6String(t, goja.New(), `let a = #;`)
-		assert.NotNil(t, err)
-		assert.Contains(t, err.Error(), "SyntaxError: __string__: Unexpected character '#' (1:8)\n> 1 | let a = #;\n")
-	})
-}
-
 // TODO replace this with the Single version
 func assertRequestMetricsEmitted(t *testing.T, sampleContainers []stats.SampleContainer, method, url, name string, status int, group string) {
 	if name == "" {
@@ -98,20 +73,20 @@ func assertRequestMetricsEmitted(t *testing.T, sampleContainers []stats.SampleCo
 		for _, sample := range sampleContainer.GetSamples() {
 			tags := sample.Tags.CloneTags()
 			if tags["url"] == url {
-				switch sample.Metric {
-				case metrics.HTTPReqDuration:
+				switch sample.Metric.Name {
+				case metrics.HTTPReqDurationName:
 					seenDuration = true
-				case metrics.HTTPReqBlocked:
+				case metrics.HTTPReqBlockedName:
 					seenBlocked = true
-				case metrics.HTTPReqConnecting:
+				case metrics.HTTPReqConnectingName:
 					seenConnecting = true
-				case metrics.HTTPReqTLSHandshaking:
+				case metrics.HTTPReqTLSHandshakingName:
 					seenTLSHandshaking = true
-				case metrics.HTTPReqSending:
+				case metrics.HTTPReqSendingName:
 					seenSending = true
-				case metrics.HTTPReqWaiting:
+				case metrics.HTTPReqWaitingName:
 					seenWaiting = true
-				case metrics.HTTPReqReceiving:
+				case metrics.HTTPReqReceivingName:
 					seenReceiving = true
 				}
 
@@ -131,12 +106,12 @@ func assertRequestMetricsEmitted(t *testing.T, sampleContainers []stats.SampleCo
 	assert.True(t, seenReceiving, "url %s didn't emit Receiving", url)
 }
 
-func assertRequestMetricsEmittedSingle(t *testing.T, sampleContainer stats.SampleContainer, expectedTags map[string]string, metrics []*stats.Metric, callback func(sample stats.Sample)) {
+func assertRequestMetricsEmittedSingle(t *testing.T, sampleContainer stats.SampleContainer, expectedTags map[string]string, metrics []string, callback func(sample stats.Sample)) {
 	t.Helper()
 
 	metricMap := make(map[string]bool, len(metrics))
 	for _, m := range metrics {
-		metricMap[m.Name] = false
+		metricMap[m] = false
 	}
 	for _, sample := range sampleContainer.GetSamples() {
 		tags := sample.Tags.CloneTags()
@@ -154,20 +129,18 @@ func assertRequestMetricsEmittedSingle(t *testing.T, sampleContainer stats.Sampl
 	}
 }
 
-func newRuntime(
-	t testing.TB,
-) (*httpmultibin.HTTPMultiBin, *lib.State, chan stats.SampleContainer, *goja.Runtime, *context.Context) {
+func newRuntime(t testing.TB) (
+	*httpmultibin.HTTPMultiBin, *lib.State, chan stats.SampleContainer, *goja.Runtime, *ModuleInstance,
+) {
 	tb := httpmultibin.NewHTTPMultiBin(t)
 
 	root, err := lib.NewGroup("", nil)
 	require.NoError(t, err)
+	registry := metrics.NewRegistry()
 
 	logger := logrus.New()
 	logger.Level = logrus.DebugLevel
 
-	rt := goja.New()
-	rt.SetFieldNameMapper(common.FieldNameMapper{})
-
 	options := lib.Options{
 		MaxRedirects: null.IntFrom(10),
 		UserAgent:    null.StringFrom("TestUserAgent"),
@@ -187,20 +160,19 @@ func newRuntime(
 		Transport: tb.HTTPTransport,
 		BPool:     bpool.NewBufferPool(1),
 		Samples:   samples,
-		Tags:      map[string]string{"group": root.Path},
+		Tags: lib.NewTagMap(map[string]string{
+			"group": root.Path,
+		}),
+		BuiltinMetrics: metrics.RegisterBuiltinMetrics(registry),
 	}
 
-	ctx := new(context.Context)
-	*ctx = lib.WithState(tb.Context, state)
-	*ctx = common.WithRuntime(*ctx, rt)
-	rt.Set("http", common.Bind(rt, new(GlobalHTTP).NewModuleInstancePerVU(), ctx))
-
-	return tb, state, samples, rt, ctx
+	rt, mi := getTestModuleInstance(t, tb.Context, state)
+	return tb, state, samples, rt, mi
 }
 
 func TestRequestAndBatch(t *testing.T) {
 	t.Parallel()
-	tb, state, samples, rt, ctx := newRuntime(t)
+	tb, state, samples, rt, _ := newRuntime(t)
 	sr := tb.Replacer.Replace
 
 	// Handle paths with custom logic
@@ -506,20 +478,6 @@ func TestRequestAndBatch(t *testing.T) {
 			assert.NoError(t, err)
 		})
 	})
-	t.Run("Cancelled", func(t *testing.T) {
-		hook := logtest.NewLocal(state.Logger)
-		defer hook.Reset()
-
-		oldctx := *ctx
-		newctx, cancel := context.WithCancel(oldctx)
-		cancel()
-		*ctx = newctx
-		defer func() { *ctx = oldctx }()
-
-		_, err := rt.RunString(sr(`http.get("HTTPBIN_URL/get/");`))
-		assert.Error(t, err)
-		assert.Nil(t, hook.LastEntry())
-	})
 	t.Run("HTTP/2", func(t *testing.T) {
 		stats.GetBufferedSamples(samples) // Clean up buffered samples from previous tests
 		_, err := rt.RunString(sr(`
@@ -1089,7 +1047,7 @@ func TestRequestAndBatch(t *testing.T) {
 			})
 
 			t.Run("name/template", func(t *testing.T) {
-				_, err := runES6String(t, rt, "http.get(http.url`"+sr(`HTTPBIN_URL/anything/${1+1}`)+"`);")
+				_, err := rt.RunString("http.get(http.url`" + sr(`HTTPBIN_URL/anything/${1+1}`) + "`);")
 				assert.NoError(t, err)
 				// There's no /anything endpoint in the go-httpbin library we're using, hence the 404,
 				// but it doesn't matter for this test.
@@ -1117,7 +1075,10 @@ func TestRequestAndBatch(t *testing.T) {
 			t.Run("tags-precedence", func(t *testing.T) {
 				oldTags := state.Tags
 				defer func() { state.Tags = oldTags }()
-				state.Tags = map[string]string{"runtag1": "val1", "runtag2": "val2"}
+				state.Tags = lib.NewTagMap(map[string]string{
+					"runtag1": "val1",
+					"runtag2": "val2",
+				})
 
 				_, err := rt.RunString(sr(`
 				var res = http.request("GET", "HTTPBIN_URL/headers", null, { tags: { method: "test", name: "myName", runtag1: "fromreq" } });
@@ -1161,10 +1122,10 @@ func TestRequestAndBatch(t *testing.T) {
 		assertRequestMetricsEmitted(t, stats.GetBufferedSamples(samples), "GET", sr("HTTPBIN_URL/get?a=1&b=2"), "", 200, "")
 
 		t.Run("Tagged", func(t *testing.T) {
-			_, err := runES6String(t, rt, `
+			_, err := rt.RunString(`
 			var a = "1";
 			var b = "2";
-			var res = http.get(http.url`+"`"+sr(`HTTPBIN_URL/get?a=${a}&b=${b}`)+"`"+`);
+			var res = http.get(http.url` + "`" + sr(`HTTPBIN_URL/get?a=${a}&b=${b}`) + "`" + `);
 			if (res.status != 200) { throw new Error("wrong status: " + res.status); }
 			if (res.json().args.a != a) { throw new Error("wrong ?a: " + res.json().args.a); }
 			if (res.json().args.b != b) { throw new Error("wrong ?b: " + res.json().args.b); }
@@ -1401,12 +1362,12 @@ func TestRequestAndBatch(t *testing.T) {
 			assertRequestMetricsEmitted(t, bufSamples, "GET", sr("HTTPBIN_IP_URL/"), "", 200, "")
 
 			t.Run("Tagged", func(t *testing.T) {
-				_, err := runES6String(t, rt, sr(`
+				_, err := rt.RunString(sr(`
 			{
 				let fragment = "get";
 				let reqs = [
-					["GET", http.url`+"`"+`HTTPBIN_URL/${fragment}`+"`"+`],
-					["GET", http.url`+"`"+`HTTPBIN_IP_URL/`+"`"+`],
+					["GET", http.url` + "`" + `HTTPBIN_URL/${fragment}` + "`" + `],
+					["GET", http.url` + "`" + `HTTPBIN_IP_URL/` + "`" + `],
 				];
 				let res = http.batch(reqs);
 				for (var key in res) {
@@ -1439,12 +1400,12 @@ func TestRequestAndBatch(t *testing.T) {
 				assertRequestMetricsEmitted(t, bufSamples, "GET", sr("HTTPBIN_IP_URL/"), "", 200, "")
 
 				t.Run("Tagged", func(t *testing.T) {
-					_, err := runES6String(t, rt, sr(`
+					_, err := rt.RunString(sr(`
 				{
 					let fragment = "get";
 					let reqs = [
-						http.url`+"`"+`HTTPBIN_URL/${fragment}`+"`"+`,
-						http.url`+"`"+`HTTPBIN_IP_URL/`+"`"+`,
+						http.url` + "`" + `HTTPBIN_URL/${fragment}` + "`" + `,
+						http.url` + "`" + `HTTPBIN_IP_URL/` + "`" + `,
 					];
 					let res = http.batch(reqs);
 					for (var key in res) {
@@ -1598,6 +1559,26 @@ func TestRequestAndBatch(t *testing.T) {
 	})
 }
 
+func TestRequestCancellation(t *testing.T) {
+	t.Parallel()
+	tb, state, _, rt, mi := newRuntime(t)
+	sr := tb.Replacer.Replace
+
+	hook := logtest.NewLocal(state.Logger)
+	defer hook.Reset()
+
+	testVU, ok := mi.vu.(*modulestest.VU)
+	require.True(t, ok)
+
+	newctx, cancel := context.WithCancel(mi.vu.Context())
+	testVU.CtxField = newctx
+	cancel()
+
+	_, err := rt.RunString(sr(`http.get("HTTPBIN_URL/get/");`))
+	assert.Error(t, err)
+	assert.Nil(t, hook.LastEntry())
+}
+
 func TestRequestArrayBufferBody(t *testing.T) {
 	t.Parallel()
 	tb, _, _, rt, _ := newRuntime(t) //nolint: dogsled
@@ -1757,8 +1738,8 @@ func TestRequestCompression(t *testing.T) {
 			}
 			expectedEncoding = strings.Join(algos, ", ")
 			actualEncoding = expectedEncoding
-			_, err := runES6String(t, rt, tb.Replacer.Replace(`
-		http.post("HTTPBIN_URL/compressed-text", `+"`"+text+"`"+`,  {"compression": "`+testCase.compression+`"});
+			_, err := rt.RunString(tb.Replacer.Replace(`
+		http.post("HTTPBIN_URL/compressed-text", ` + "`" + text + "`" + `,  {"compression": "` + testCase.compression + `"});
 	`))
 			if testCase.expectedError == "" {
 				require.NoError(t, err)
@@ -1775,10 +1756,10 @@ func TestRequestCompression(t *testing.T) {
 
 		logHook.Drain()
 		t.Run("encoding", func(t *testing.T) {
-			_, err := runES6String(t, rt, tb.Replacer.Replace(`
-				http.post("HTTPBIN_URL/compressed-text", `+"`"+text+"`"+`,
-					{"compression": "`+actualEncoding+`",
-					 "headers": {"Content-Encoding": "`+expectedEncoding+`"}
+			_, err := rt.RunString(tb.Replacer.Replace(`
+				http.post("HTTPBIN_URL/compressed-text", ` + "`" + text + "`" + `,
+					{"compression": "` + actualEncoding + `",
+					 "headers": {"Content-Encoding": "` + expectedEncoding + `"}
 					}
 				);
 			`))
@@ -1787,10 +1768,10 @@ func TestRequestCompression(t *testing.T) {
 		})
 
 		t.Run("encoding and length", func(t *testing.T) {
-			_, err := runES6String(t, rt, tb.Replacer.Replace(`
-				http.post("HTTPBIN_URL/compressed-text", `+"`"+text+"`"+`,
-					{"compression": "`+actualEncoding+`",
-					 "headers": {"Content-Encoding": "`+expectedEncoding+`",
+			_, err := rt.RunString(tb.Replacer.Replace(`
+				http.post("HTTPBIN_URL/compressed-text", ` + "`" + text + "`" + `,
+					{"compression": "` + actualEncoding + `",
+					 "headers": {"Content-Encoding": "` + expectedEncoding + `",
 								 "Content-Length": "12"}
 					}
 				);
@@ -1801,10 +1782,10 @@ func TestRequestCompression(t *testing.T) {
 
 		expectedEncoding = actualEncoding
 		t.Run("correct encoding", func(t *testing.T) {
-			_, err := runES6String(t, rt, tb.Replacer.Replace(`
-				http.post("HTTPBIN_URL/compressed-text", `+"`"+text+"`"+`,
-					{"compression": "`+actualEncoding+`",
-					 "headers": {"Content-Encoding": "`+actualEncoding+`"}
+			_, err := rt.RunString(tb.Replacer.Replace(`
+				http.post("HTTPBIN_URL/compressed-text", ` + "`" + text + "`" + `,
+					{"compression": "` + actualEncoding + `",
+					 "headers": {"Content-Encoding": "` + actualEncoding + `"}
 					}
 				);
 			`))
