@@ -28,8 +28,8 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
-	"go.k6.io/k6/lib/netext/httpext"
 	"go.k6.io/k6/stats"
 )
 
@@ -124,6 +124,7 @@ func invalidJSONHandler(w http.ResponseWriter, r *http.Request) {
 	_, _ = w.Write(body)
 }
 
+//nolint:paralleltest
 func TestResponse(t *testing.T) {
 	tb, state, samples, rt, _ := newRuntime(t)
 	root := state.Group
@@ -168,10 +169,10 @@ func TestResponse(t *testing.T) {
 			if assert.NoError(t, err) {
 				old := state.Group
 				state.Group = g
-				state.Tags["group"] = g.Path
+				state.Tags.Set("group", g.Path)
 				defer func() {
 					state.Group = old
-					state.Tags["group"] = old.Path
+					state.Tags.Set("group", old.Path)
 				}()
 			}
 
@@ -183,6 +184,13 @@ func TestResponse(t *testing.T) {
 			assert.NoError(t, err)
 			assertRequestMetricsEmitted(t, stats.GetBufferedSamples(samples), "GET", sr("HTTPBIN_URL/html"), "", 200, "::my group")
 		})
+
+		t.Run("NoResponseBody", func(t *testing.T) {
+			_, err := rt.RunString(sr(`http.get("HTTPBIN_URL/html", {responseType: 'none'}).html();`))
+			require.NotNil(t, err)
+			assert.Contains(t, err.Error(), "the body is null so we can't transform it to HTML"+
+				" - this likely was because of a request error getting the response")
+		})
 	})
 	t.Run("Json", func(t *testing.T) {
 		_, err := rt.RunString(sr(`
@@ -205,6 +213,12 @@ func TestResponse(t *testing.T) {
 			//nolint:lll
 			assert.Contains(t, err.Error(), "cannot parse json due to an error at line 3, character 9 , error: invalid character 'e' in literal true (expecting 'r')")
 		})
+
+		t.Run("NoResponseBody", func(t *testing.T) {
+			_, err := rt.RunString(sr(`http.get("HTTPBIN_URL/json", {responseType: 'none'}).json();`))
+			assert.Contains(t, err.Error(), "the body is null so we can't transform it to JSON"+
+				" - this likely was because of a request error getting the response")
+		})
 	})
 	t.Run("JsonSelector", func(t *testing.T) {
 		_, err := rt.RunString(sr(`
@@ -343,7 +357,7 @@ func TestResponse(t *testing.T) {
 					data.textarea[0] !== "Lorem ipsum dolor sit amet"
 				) { throw new Error("incorrect body: " + JSON.stringify(data, null, 4) ); }
 			`))
-			assert.NoError(t, err)
+			require.NoError(t, err)
 			assertRequestMetricsEmitted(t, stats.GetBufferedSamples(samples), "GET", sr("HTTPBIN_URL/myforms/get"), "", 200, "")
 		})
 	})
@@ -394,35 +408,3 @@ func TestResponse(t *testing.T) {
 		})
 	})
 }
-
-func BenchmarkResponseJson(b *testing.B) {
-	b.Skipf("We need to have context in the response")
-	testCases := []struct {
-		selector string
-	}{
-		{"glossary.GlossDiv.GlossList.GlossEntry.title"},
-		{"glossary.GlossDiv.GlossList.GlossEntry.int"},
-		{"glossary.GlossDiv.GlossList.GlossEntry.intArray"},
-		{"glossary.GlossDiv.GlossList.GlossEntry.mixedArray"},
-		{"glossary.friends"},
-		{"glossary.friends.#.first"},
-		{"glossary.GlossDiv.GlossList.GlossEntry.GlossDef"},
-		{"glossary"},
-	}
-	for _, tc := range testCases {
-		tc := tc
-		b.Run(fmt.Sprintf("Selector %s ", tc.selector), func(b *testing.B) {
-			for n := 0; n < b.N; n++ {
-				resp := new(HTTP).responseFromHttpext(&httpext.Response{Body: jsonData})
-				resp.JSON(tc.selector)
-			}
-		})
-	}
-
-	b.Run("Without selector", func(b *testing.B) {
-		for n := 0; n < b.N; n++ {
-			resp := new(HTTP).responseFromHttpext(&httpext.Response{Body: jsonData})
-			resp.JSON()
-		}
-	})
-}
