@@ -32,6 +32,7 @@ import (
 	"github.com/stretchr/testify/require"
 
 	"go.k6.io/k6/js/common"
+	"go.k6.io/k6/js/modulestest"
 	"go.k6.io/k6/lib"
 	"go.k6.io/k6/lib/metrics"
 	"go.k6.io/k6/stats"
@@ -40,7 +41,17 @@ import (
 func TestFail(t *testing.T) {
 	t.Parallel()
 	rt := goja.New()
-	require.NoError(t, rt.Set("k6", common.Bind(rt, New(), nil)))
+	m, ok := New().NewModuleInstance(
+		&modulestest.VU{
+			RuntimeField: rt,
+			InitEnvField: &common.InitEnvironment{},
+			CtxField:     common.WithRuntime(context.Background(), rt),
+			StateField:   nil,
+		},
+	).(*K6)
+	require.True(t, ok)
+	require.NoError(t, rt.Set("k6", m.Exports().Named))
+
 	_, err := rt.RunString(`k6.fail("blah")`)
 	assert.Contains(t, err.Error(), "blah")
 }
@@ -58,8 +69,17 @@ func TestSleep(t *testing.T) {
 		t.Run(name, func(t *testing.T) {
 			t.Parallel()
 			rt := goja.New()
-			ctx := context.Background()
-			require.NoError(t, rt.Set("k6", common.Bind(rt, New(), &ctx)))
+			m, ok := New().NewModuleInstance(
+				&modulestest.VU{
+					RuntimeField: rt,
+					InitEnvField: &common.InitEnvironment{},
+					CtxField:     common.WithRuntime(context.Background(), rt),
+					StateField:   nil,
+				},
+			).(*K6)
+			require.True(t, ok)
+			require.NoError(t, rt.Set("k6", m.Exports().Named))
+
 			startTime := time.Now()
 			_, err := rt.RunString(`k6.sleep(1)`)
 			endTime := time.Now()
@@ -72,7 +92,17 @@ func TestSleep(t *testing.T) {
 		t.Parallel()
 		rt := goja.New()
 		ctx, cancel := context.WithCancel(context.Background())
-		require.NoError(t, rt.Set("k6", common.Bind(rt, New(), &ctx)))
+		m, ok := New().NewModuleInstance(
+			&modulestest.VU{
+				RuntimeField: rt,
+				InitEnvField: &common.InitEnvironment{},
+				CtxField:     common.WithRuntime(ctx, rt),
+				StateField:   nil,
+			},
+		).(*K6)
+		require.True(t, ok)
+		require.NoError(t, rt.Set("k6", m.Exports().Named))
+
 		dch := make(chan time.Duration)
 		go func() {
 			startTime := time.Now()
@@ -96,10 +126,16 @@ func TestRandSeed(t *testing.T) {
 	t.Parallel()
 	rt := goja.New()
 
-	ctx := context.Background()
-	ctx = common.WithRuntime(ctx, rt)
-
-	require.NoError(t, rt.Set("k6", common.Bind(rt, New(), &ctx)))
+	m, ok := New().NewModuleInstance(
+		&modulestest.VU{
+			RuntimeField: rt,
+			InitEnvField: &common.InitEnvironment{},
+			CtxField:     common.WithRuntime(context.Background(), rt),
+			StateField:   nil,
+		},
+	).(*K6)
+	require.True(t, ok)
+	require.NoError(t, rt.Set("k6", m.Exports().Named))
 
 	rand := 0.8487305991992138
 	_, err := rt.RunString(fmt.Sprintf(`
@@ -123,12 +159,26 @@ func TestGroup(t *testing.T) {
 		assert.NoError(t, err)
 
 		rt := goja.New()
-		state := &lib.State{Group: root, Samples: make(chan stats.SampleContainer, 1000)}
-
-		ctx := context.Background()
-		ctx = lib.WithState(ctx, state)
-		ctx = common.WithRuntime(ctx, rt)
-		require.NoError(t, rt.Set("k6", common.Bind(rt, New(), &ctx)))
+		state := &lib.State{
+			Group:   root,
+			Samples: make(chan stats.SampleContainer, 1000),
+			Tags:    lib.NewTagMap(nil),
+			Options: lib.Options{
+				SystemTags: stats.NewSystemTagSet(stats.TagGroup),
+			},
+		}
+		ctx := lib.WithState(context.Background(), state)
+		state.BuiltinMetrics = metrics.RegisterBuiltinMetrics(metrics.NewRegistry())
+		m, ok := New().NewModuleInstance(
+			&modulestest.VU{
+				RuntimeField: rt,
+				InitEnvField: &common.InitEnvironment{},
+				CtxField:     common.WithRuntime(ctx, rt),
+				StateField:   state,
+			},
+		).(*K6)
+		require.True(t, ok)
+		require.NoError(t, rt.Set("k6", m.Exports().Named))
 		return rt, state, root
 	}
 
@@ -137,12 +187,18 @@ func TestGroup(t *testing.T) {
 		rt, state, root := setupGroupTest()
 		assert.Equal(t, state.Group, root)
 		require.NoError(t, rt.Set("fn", func() {
+			groupTag, ok := state.Tags.Get("group")
+			require.True(t, ok)
+			assert.Equal(t, groupTag, "::my group")
 			assert.Equal(t, state.Group.Name, "my group")
 			assert.Equal(t, state.Group.Parent, root)
 		}))
 		_, err := rt.RunString(`k6.group("my group", fn)`)
 		assert.NoError(t, err)
 		assert.Equal(t, state.Group, root)
+		groupTag, ok := state.Tags.Get("group")
+		require.True(t, ok)
+		assert.Equal(t, groupTag, root.Name)
 	})
 
 	t.Run("Invalid", func(t *testing.T) {
@@ -154,7 +210,7 @@ func TestGroup(t *testing.T) {
 }
 
 func checkTestRuntime(t testing.TB, ctxs ...*context.Context) (
-	*goja.Runtime, chan stats.SampleContainer,
+	*goja.Runtime, chan stats.SampleContainer, *metrics.BuiltinMetrics,
 ) {
 	rt := goja.New()
 
@@ -167,7 +223,9 @@ func checkTestRuntime(t testing.TB, ctxs ...*context.Context) (
 			SystemTags: &stats.DefaultSystemTagSet,
 		},
 		Samples: samples,
-		Tags:    map[string]string{"group": root.Path},
+		Tags: lib.NewTagMap(map[string]string{
+			"group": root.Path,
+		}),
 	}
 	ctx := context.Background()
 	if len(ctxs) == 1 { // hacks
@@ -175,16 +233,26 @@ func checkTestRuntime(t testing.TB, ctxs ...*context.Context) (
 	}
 	ctx = common.WithRuntime(ctx, rt)
 	ctx = lib.WithState(ctx, state)
-	require.NoError(t, rt.Set("k6", common.Bind(rt, New(), &ctx)))
+	state.BuiltinMetrics = metrics.RegisterBuiltinMetrics(metrics.NewRegistry())
+	m, ok := New().NewModuleInstance(
+		&modulestest.VU{
+			RuntimeField: rt,
+			InitEnvField: &common.InitEnvironment{},
+			CtxField:     ctx,
+			StateField:   state,
+		},
+	).(*K6)
+	require.True(t, ok)
+	require.NoError(t, rt.Set("k6", m.Exports().Named))
 	if len(ctxs) == 1 { // hacks
 		*ctxs[0] = ctx
 	}
-	return rt, samples
+	return rt, samples, state.BuiltinMetrics
 }
 
 func TestCheckObject(t *testing.T) {
 	t.Parallel()
-	rt, samples := checkTestRuntime(t)
+	rt, samples, builtinMetrics := checkTestRuntime(t)
 
 	_, err := rt.RunString(`k6.check(null, { "check": true })`)
 	assert.NoError(t, err)
@@ -195,7 +263,7 @@ func TestCheckObject(t *testing.T) {
 		require.True(t, ok)
 
 		assert.NotZero(t, sample.Time)
-		assert.Equal(t, metrics.Checks, sample.Metric)
+		assert.Equal(t, builtinMetrics.Checks, sample.Metric)
 		assert.Equal(t, float64(1), sample.Value)
 		assert.Equal(t, map[string]string{
 			"group": "",
@@ -205,7 +273,7 @@ func TestCheckObject(t *testing.T) {
 
 	t.Run("Multiple", func(t *testing.T) {
 		t.Parallel()
-		rt, samples := checkTestRuntime(t)
+		rt, samples, _ := checkTestRuntime(t)
 
 		_, err := rt.RunString(`k6.check(null, { "a": true, "b": false })`)
 		assert.NoError(t, err)
@@ -235,7 +303,7 @@ func TestCheckObject(t *testing.T) {
 
 	t.Run("Invalid", func(t *testing.T) {
 		t.Parallel()
-		rt, _ := checkTestRuntime(t)
+		rt, _, _ := checkTestRuntime(t)
 		_, err := rt.RunString(`k6.check(null, { "::": true })`)
 		assert.Contains(t, err.Error(), "group and check names may not contain '::'")
 	})
@@ -243,7 +311,7 @@ func TestCheckObject(t *testing.T) {
 
 func TestCheckArray(t *testing.T) {
 	t.Parallel()
-	rt, samples := checkTestRuntime(t)
+	rt, samples, builtinMetrics := checkTestRuntime(t)
 
 	_, err := rt.RunString(`k6.check(null, [ true ])`)
 	assert.NoError(t, err)
@@ -254,7 +322,7 @@ func TestCheckArray(t *testing.T) {
 		require.True(t, ok)
 
 		assert.NotZero(t, sample.Time)
-		assert.Equal(t, metrics.Checks, sample.Metric)
+		assert.Equal(t, builtinMetrics.Checks, sample.Metric)
 		assert.Equal(t, float64(1), sample.Value)
 		assert.Equal(t, map[string]string{
 			"group": "",
@@ -265,7 +333,7 @@ func TestCheckArray(t *testing.T) {
 
 func TestCheckLiteral(t *testing.T) {
 	t.Parallel()
-	rt, samples := checkTestRuntime(t)
+	rt, samples, _ := checkTestRuntime(t)
 
 	_, err := rt.RunString(`k6.check(null, 12345)`)
 	assert.NoError(t, err)
@@ -274,14 +342,14 @@ func TestCheckLiteral(t *testing.T) {
 
 func TestCheckThrows(t *testing.T) {
 	t.Parallel()
-	rt, samples := checkTestRuntime(t)
+	rt, samples, builtinMetrics := checkTestRuntime(t)
 	_, err := rt.RunString(`
 		k6.check(null, {
 			"a": function() { throw new Error("error A") },
 			"b": function() { throw new Error("error B") },
 		})
 		`)
-	assert.EqualError(t, err, "Error: error A at a (<eval>:3:28(4))")
+	assert.EqualError(t, err, "Error: error A at a (<eval>:3:28(3))")
 
 	bufSamples := stats.GetBufferedSamples(samples)
 	if assert.Len(t, bufSamples, 1) {
@@ -289,7 +357,7 @@ func TestCheckThrows(t *testing.T) {
 		require.True(t, ok)
 
 		assert.NotZero(t, sample.Time)
-		assert.Equal(t, metrics.Checks, sample.Metric)
+		assert.Equal(t, builtinMetrics.Checks, sample.Metric)
 		assert.Equal(t, float64(0), sample.Value)
 		assert.Equal(t, map[string]string{
 			"group": "",
@@ -325,7 +393,7 @@ func TestCheckTypes(t *testing.T) {
 				value, succ := value, succ
 				t.Run(value, func(t *testing.T) {
 					t.Parallel()
-					rt, samples := checkTestRuntime(t)
+					rt, samples, builtinMetrics := checkTestRuntime(t)
 
 					v, err := rt.RunString(fmt.Sprintf(tpl, value))
 					if assert.NoError(t, err) {
@@ -338,7 +406,7 @@ func TestCheckTypes(t *testing.T) {
 						require.True(t, ok)
 
 						assert.NotZero(t, sample.Time)
-						assert.Equal(t, metrics.Checks, sample.Metric)
+						assert.Equal(t, builtinMetrics.Checks, sample.Metric)
 						if succ {
 							assert.Equal(t, float64(1), sample.Value)
 						} else {
@@ -358,7 +426,7 @@ func TestCheckTypes(t *testing.T) {
 func TestCheckContextExpiry(t *testing.T) {
 	t.Parallel()
 	ctx, cancel := context.WithCancel(context.Background())
-	rt, _ := checkTestRuntime(t, &ctx)
+	rt, _, _ := checkTestRuntime(t, &ctx)
 	root := lib.GetState(ctx).Group
 
 	v, err := rt.RunString(`k6.check(null, { "check": true })`)
@@ -383,7 +451,7 @@ func TestCheckContextExpiry(t *testing.T) {
 
 func TestCheckTags(t *testing.T) {
 	t.Parallel()
-	rt, samples := checkTestRuntime(t)
+	rt, samples, builtinMetrics := checkTestRuntime(t)
 
 	v, err := rt.RunString(`k6.check(null, {"check": true}, {a: 1, b: "2"})`)
 	if assert.NoError(t, err) {
@@ -396,7 +464,7 @@ func TestCheckTags(t *testing.T) {
 		require.True(t, ok)
 
 		assert.NotZero(t, sample.Time)
-		assert.Equal(t, metrics.Checks, sample.Metric)
+		assert.Equal(t, builtinMetrics.Checks, sample.Metric)
 		assert.Equal(t, float64(1), sample.Value)
 		assert.Equal(t, map[string]string{
 			"group": "",
