@@ -37,16 +37,53 @@ import (
 	"github.com/gorilla/websocket"
 
 	"go.k6.io/k6/js/common"
-	"go.k6.io/k6/lib"
+	"go.k6.io/k6/js/modules"
+	httpModule "go.k6.io/k6/js/modules/k6/http"
 	"go.k6.io/k6/lib/metrics"
 	"go.k6.io/k6/stats"
 )
 
+type (
+	// RootModule is the global module instance that will create module
+	// instances for each VU.
+	RootModule struct{}
+
+	// WS represents a module instance of the WebSocket module.
+	WS struct {
+		vu  modules.VU
+		obj *goja.Object
+	}
+)
+
+var (
+	_ modules.Module   = &RootModule{}
+	_ modules.Instance = &WS{}
+)
+
+// New returns a pointer to a new RootModule instance.
+func New() *RootModule {
+	return &RootModule{}
+}
+
+// NewModuleInstance implements the modules.Module interface to return
+// a new instance for each VU.
+func (*RootModule) NewModuleInstance(m modules.VU) modules.Instance {
+	rt := m.Runtime()
+	mi := &WS{
+		vu: m,
+	}
+	obj := rt.NewObject()
+	if err := obj.Set("connect", mi.Connect); err != nil {
+		common.Throw(rt, err)
+	}
+
+	mi.obj = obj
+	return mi
+}
+
 // ErrWSInInitContext is returned when websockets are using in the init context
 var ErrWSInInitContext = common.NewInitContextError("using websockets in the init context is not supported")
 
-type WS struct{}
-
 type Socket struct {
 	ctx           context.Context
 	conn          *websocket.Conn
@@ -58,8 +95,9 @@ type Socket struct {
 	pingSendTimestamps map[string]time.Time
 	pingSendCounter    int
 
-	sampleTags    *stats.SampleTags
-	samplesOutput chan<- stats.SampleContainer
+	sampleTags     *stats.SampleTags
+	samplesOutput  chan<- stats.SampleContainer
+	builtinMetrics *metrics.BuiltinMetrics
 }
 
 type WSHTTPResponse struct {
@@ -77,13 +115,18 @@ type message struct {
 
 const writeWait = 10 * time.Second
 
-func New() *WS {
-	return &WS{}
+// Exports returns the exports of the ws module.
+func (mi *WS) Exports() modules.Exports {
+	return modules.Exports{Default: mi.obj}
 }
 
-func (*WS) Connect(ctx context.Context, url string, args ...goja.Value) (*WSHTTPResponse, error) {
-	rt := common.GetRuntime(ctx)
-	state := lib.GetState(ctx)
+// Connect establishes a WebSocket connection based on the parameters provided.
+// TODO: refactor to reduce the method complexity
+//nolint: funlen,gocognit,gocyclo,cyclop
+func (mi *WS) Connect(url string, args ...goja.Value) (*WSHTTPResponse, error) {
+	ctx := mi.vu.Context()
+	rt := mi.vu.Runtime()
+	state := mi.vu.State()
 	if state == nil {
 		return nil, ErrWSInInitContext
 	}
@@ -100,17 +143,19 @@ func (*WS) Connect(ctx context.Context, url string, args ...goja.Value) (*WSHTTP
 	default:
 		return nil, errors.New("invalid number of arguments to ws.connect")
 	}
-
 	// Get the callable (required)
 	setupFn, isFunc := goja.AssertFunction(callableV)
 	if !isFunc {
 		return nil, errors.New("last argument to ws.connect must be a function")
 	}
 
-	// Leave header to nil by default so we can pass it directly to the Dialer
-	var header http.Header
+	header := make(http.Header)
+	header.Set("User-Agent", state.Options.UserAgent.String)
+
+	enableCompression := false
 
 	tags := state.CloneTags()
+	jar := state.CookieJar
 
 	// Parse the optional second argument (params)
 	if !goja.IsUndefined(paramsV) && !goja.IsNull(paramsV) {
@@ -118,7 +163,6 @@ func (*WS) Connect(ctx context.Context, url string, args ...goja.Value) (*WSHTTP
 		for _, k := range params.Keys() {
 			switch k {
 			case "headers":
-				header = http.Header{}
 				headersV := params.Get(k)
 				if goja.IsUndefined(headersV) || goja.IsNull(headersV) {
 					continue
@@ -142,6 +186,30 @@ func (*WS) Connect(ctx context.Context, url string, args ...goja.Value) (*WSHTTP
 				for _, key := range tagObj.Keys() {
 					tags[key] = tagObj.Get(key).String()
 				}
+			case "jar":
+				jarV := params.Get(k)
+				if goja.IsUndefined(jarV) || goja.IsNull(jarV) {
+					continue
+				}
+				if v, ok := jarV.Export().(*httpModule.CookieJar); ok {
+					jar = v.Jar
+				}
+			case "compression":
+				// deflate compression algorithm is supported - as defined in RFC7692
+				// compression here relies on the implementation in gorilla/websocket package, usage is
+				// experimental and may result in decreased performance. package supports
+				// only "no context takeover" scenario
+
+				algoString := strings.TrimSpace(params.Get(k).ToString().String())
+				if algoString == "" {
+					continue
+				}
+
+				if algoString != "deflate" {
+					return nil, fmt.Errorf("unsupported compression algorithm '%s', supported algorithm is 'deflate'", algoString)
+				}
+
+				enableCompression = true
 			}
 		}
 
@@ -162,9 +230,14 @@ func (*WS) Connect(ctx context.Context, url string, args ...goja.Value) (*WSHTTP
 		HandshakeTimeout: time.Second * 60, // TODO configurable
 		// Pass a custom net.DialContext function to websocket.Dialer that will substitute
 		// the underlying net.Conn with our own tracked netext.Conn
-		NetDialContext:  state.Dialer.DialContext,
-		Proxy:           http.ProxyFromEnvironment,
-		TLSClientConfig: tlsConfig,
+		NetDialContext:    state.Dialer.DialContext,
+		Proxy:             http.ProxyFromEnvironment,
+		TLSClientConfig:   tlsConfig,
+		EnableCompression: enableCompression,
+		Jar:               jar,
+	}
+	if jar == nil { // this is needed because of how interfaces work and that wsd.Jar is http.Cookiejar
+		wsd.Jar = nil
 	}
 
 	start := time.Now()
@@ -197,12 +270,13 @@ func (*WS) Connect(ctx context.Context, url string, args ...goja.Value) (*WSHTTP
 		done:               make(chan struct{}),
 		samplesOutput:      state.Samples,
 		sampleTags:         stats.IntoSampleTags(&tags),
+		builtinMetrics:     state.BuiltinMetrics,
 	}
 
 	stats.PushIfNotDone(ctx, state.Samples, stats.ConnectedSamples{
 		Samples: []stats.Sample{
-			{Metric: metrics.WSSessions, Time: start, Tags: socket.sampleTags, Value: 1},
-			{Metric: metrics.WSConnecting, Time: start, Tags: socket.sampleTags, Value: connectionDuration},
+			{Metric: state.BuiltinMetrics.WSSessions, Time: start, Tags: socket.sampleTags, Value: 1},
+			{Metric: state.BuiltinMetrics.WSConnecting, Time: start, Tags: socket.sampleTags, Value: connectionDuration},
 		},
 		Tags: socket.sampleTags,
 		Time: start,
@@ -220,7 +294,6 @@ func (*WS) Connect(ctx context.Context, url string, args ...goja.Value) (*WSHTTP
 		_ = socket.closeConnection(websocket.CloseGoingAway)
 		return nil, err
 	}
-
 	wsResponse, wsRespErr := wrapHTTPResponse(httpResponse)
 	if wsRespErr != nil {
 		return nil, wsRespErr
@@ -259,7 +332,7 @@ func (*WS) Connect(ctx context.Context, url string, args ...goja.Value) (*WSHTTP
 		sessionDuration := stats.D(end.Sub(start))
 
 		stats.PushIfNotDone(ctx, state.Samples, stats.Sample{
-			Metric: metrics.WSSessionDuration,
+			Metric: socket.builtinMetrics.WSSessionDuration,
 			Tags:   socket.sampleTags,
 			Time:   start,
 			Value:  sessionDuration,
@@ -287,7 +360,7 @@ func (*WS) Connect(ctx context.Context, url string, args ...goja.Value) (*WSHTTP
 
 		case msg := <-readDataChan:
 			stats.PushIfNotDone(ctx, socket.samplesOutput, stats.Sample{
-				Metric: metrics.WSMessagesReceived,
+				Metric: socket.builtinMetrics.WSMessagesReceived,
 				Time:   time.Now(),
 				Tags:   socket.sampleTags,
 				Value:  1,
@@ -347,7 +420,7 @@ func (s *Socket) Send(message string) {
 	}
 
 	stats.PushIfNotDone(s.ctx, s.samplesOutput, stats.Sample{
-		Metric: metrics.WSMessagesSent,
+		Metric: s.builtinMetrics.WSMessagesSent,
 		Time:   time.Now(),
 		Tags:   s.sampleTags,
 		Value:  1,
@@ -378,7 +451,7 @@ func (s *Socket) SendBinary(message goja.Value) {
 	}
 
 	stats.PushIfNotDone(s.ctx, s.samplesOutput, stats.Sample{
-		Metric: metrics.WSMessagesSent,
+		Metric: s.builtinMetrics.WSMessagesSent,
 		Time:   time.Now(),
 		Tags:   s.sampleTags,
 		Value:  1,
@@ -412,7 +485,7 @@ func (s *Socket) trackPong(pingID string) {
 	pingTimestamp := s.pingSendTimestamps[pingID]
 
 	stats.PushIfNotDone(s.ctx, s.samplesOutput, stats.Sample{
-		Metric: metrics.WSPing,
+		Metric: s.builtinMetrics.WSPing,
 		Time:   pongTimestamp,
 		Tags:   s.sampleTags,
 		Value:  stats.D(pongTimestamp.Sub(pingTimestamp)),
