@@ -31,6 +31,7 @@ import (
 	"net"
 	"net/http"
 	"net/http/cookiejar"
+	"os"
 	"runtime/debug"
 	"strconv"
 	"strings"
@@ -48,6 +49,7 @@ import (
 	"go.k6.io/k6/js/common"
 	"go.k6.io/k6/lib"
 	"go.k6.io/k6/lib/consts"
+	"go.k6.io/k6/lib/metrics"
 	"go.k6.io/k6/lib/netext"
 	"go.k6.io/k6/lib/types"
 	"go.k6.io/k6/loader"
@@ -58,9 +60,11 @@ import (
 var _ lib.Runner = &Runner{}
 
 type Runner struct {
-	Bundle       *Bundle
-	Logger       *logrus.Logger
-	defaultGroup *lib.Group
+	Bundle         *Bundle
+	Logger         *logrus.Logger
+	defaultGroup   *lib.Group
+	builtinMetrics *metrics.BuiltinMetrics
+	registry       *metrics.Registry
 
 	BaseDialer net.Dialer
 	Resolver   netext.Resolver
@@ -75,26 +79,33 @@ type Runner struct {
 // New returns a new Runner for the provide source
 func New(
 	logger *logrus.Logger, src *loader.SourceData, filesystems map[string]afero.Fs, rtOpts lib.RuntimeOptions,
+	builtinMetrics *metrics.BuiltinMetrics, registry *metrics.Registry,
 ) (*Runner, error) {
-	bundle, err := NewBundle(logger, src, filesystems, rtOpts)
+	bundle, err := NewBundle(logger, src, filesystems, rtOpts, registry)
 	if err != nil {
 		return nil, err
 	}
 
-	return newFromBundle(logger, bundle)
+	return NewFromBundle(logger, bundle, builtinMetrics, registry)
 }
 
 // NewFromArchive returns a new Runner from the source in the provided archive
-func NewFromArchive(logger *logrus.Logger, arc *lib.Archive, rtOpts lib.RuntimeOptions) (*Runner, error) {
-	bundle, err := NewBundleFromArchive(logger, arc, rtOpts)
+func NewFromArchive(
+	logger *logrus.Logger, arc *lib.Archive, rtOpts lib.RuntimeOptions,
+	builtinMetrics *metrics.BuiltinMetrics, registry *metrics.Registry,
+) (*Runner, error) {
+	bundle, err := NewBundleFromArchive(logger, arc, rtOpts, registry)
 	if err != nil {
 		return nil, err
 	}
 
-	return newFromBundle(logger, bundle)
+	return NewFromBundle(logger, bundle, builtinMetrics, registry)
 }
 
-func newFromBundle(logger *logrus.Logger, b *Bundle) (*Runner, error) {
+// NewFromBundle returns a new Runner from the provided Bundle
+func NewFromBundle(
+	logger *logrus.Logger, b *Bundle, builtinMetrics *metrics.BuiltinMetrics, registry *metrics.Registry,
+) (*Runner, error) {
 	defaultGroup, err := lib.NewGroup("", nil)
 	if err != nil {
 		return nil, err
@@ -114,6 +125,8 @@ func newFromBundle(logger *logrus.Logger, b *Bundle) (*Runner, error) {
 		Resolver: netext.NewResolver(
 			net.LookupIP, 0, defDNS.Select.DNSSelect, defDNS.Policy.DNSPolicy),
 		ActualResolver: net.LookupIP,
+		builtinMetrics: builtinMetrics,
+		registry:       registry,
 	}
 
 	err = r.SetOptions(r.Bundle.Options)
@@ -199,7 +212,12 @@ func (r *Runner) newVU(idLocal, idGlobal uint64, samplesOut chan<- stats.SampleC
 		MaxIdleConns:        int(r.Bundle.Options.Batch.Int64),
 		MaxIdleConnsPerHost: int(r.Bundle.Options.BatchPerHost.Int64),
 	}
-	_ = http2.ConfigureTransport(transport)
+
+	if forceHTTP1() {
+		transport.TLSNextProto = make(map[string]func(string, *tls.Conn) http.RoundTripper) // send over h1 protocol
+	} else {
+		_ = http2.ConfigureTransport(transport) // send over h2 protocol
+	}
 
 	cookieJar, err := cookiejar.New(nil)
 	if err != nil {
@@ -223,19 +241,20 @@ func (r *Runner) newVU(idLocal, idGlobal uint64, samplesOut chan<- stats.SampleC
 	}
 
 	vu.state = &lib.State{
-		Logger:     vu.Runner.Logger,
-		Options:    vu.Runner.Bundle.Options,
-		Transport:  vu.Transport,
-		Dialer:     vu.Dialer,
-		TLSConfig:  vu.TLSConfig,
-		CookieJar:  cookieJar,
-		RPSLimit:   vu.Runner.RPSLimit,
-		BPool:      vu.BPool,
-		VUID:       vu.ID,
-		VUIDGlobal: vu.IDGlobal,
-		Samples:    vu.Samples,
-		Tags:       vu.Runner.Bundle.Options.RunTags.CloneTags(),
-		Group:      r.defaultGroup,
+		Logger:         vu.Runner.Logger,
+		Options:        vu.Runner.Bundle.Options,
+		Transport:      vu.Transport,
+		Dialer:         vu.Dialer,
+		TLSConfig:      vu.TLSConfig,
+		CookieJar:      cookieJar,
+		RPSLimit:       vu.Runner.RPSLimit,
+		BPool:          vu.BPool,
+		VUID:           vu.ID,
+		VUIDGlobal:     vu.IDGlobal,
+		Samples:        vu.Samples,
+		Tags:           lib.NewTagMap(vu.Runner.Bundle.Options.RunTags.CloneTags()),
+		Group:          r.defaultGroup,
+		BuiltinMetrics: r.builtinMetrics,
 	}
 	vu.Runtime.Set("console", common.Bind(vu.Runtime, vu.Console, vu.Context))
 
@@ -250,6 +269,23 @@ func (r *Runner) newVU(idLocal, idGlobal uint64, samplesOut chan<- stats.SampleC
 	return vu, nil
 }
 
+// forceHTTP1 checks if force http1 env variable has been set in order to force requests to be sent over h1
+// TODO: This feature is temporary until #936 is resolved
+func forceHTTP1() bool {
+	godebug := os.Getenv("GODEBUG")
+	if godebug == "" {
+		return false
+	}
+	variables := strings.SplitAfter(godebug, ",")
+
+	for _, v := range variables {
+		if strings.Trim(v, ",") == "http2client=0" {
+			return true
+		}
+	}
+	return false
+}
+
 // Setup runs the setup function if there is one and sets the setupData to the returned value
 func (r *Runner) Setup(ctx context.Context, out chan<- stats.SampleContainer) error {
 	setupCtx, setupCancel := context.WithTimeout(ctx, r.getTimeoutFor(consts.SetupFn))
@@ -493,7 +529,7 @@ func (r *Runner) runPart(ctx context.Context, out chan<- stats.SampleContainer,
 	}
 
 	if r.Bundle.Options.SystemTags.Has(stats.TagGroup) {
-		vu.state.Tags["group"] = group.Path
+		vu.state.Tags.Set("group", group.Path)
 	}
 	vu.state.Group = group
 
@@ -517,9 +553,9 @@ func (r *Runner) getTimeoutFor(stage string) time.Duration {
 	d := time.Duration(0)
 	switch stage {
 	case consts.SetupFn:
-		return time.Duration(r.Bundle.Options.SetupTimeout.Duration)
+		return r.Bundle.Options.SetupTimeout.TimeDuration()
 	case consts.TeardownFn:
-		return time.Duration(r.Bundle.Options.TeardownTimeout.Duration)
+		return r.Bundle.Options.TeardownTimeout.TimeDuration()
 	case consts.HandleSummaryFn:
 		return 2 * time.Minute // TODO: make configurable
 	}
@@ -592,21 +628,21 @@ func (u *VU) Activate(params *lib.VUActivationParams) lib.ActiveVU {
 
 	opts := u.Runner.Bundle.Options
 	// TODO: maybe we can cache the original tags only clone them and add (if any) new tags on top ?
-	u.state.Tags = opts.RunTags.CloneTags()
+	u.state.Tags = lib.NewTagMap(opts.RunTags.CloneTags())
 	for k, v := range params.Tags {
-		u.state.Tags[k] = v
+		u.state.Tags.Set(k, v)
 	}
 	if opts.SystemTags.Has(stats.TagVU) {
-		u.state.Tags["vu"] = strconv.FormatUint(u.ID, 10)
+		u.state.Tags.Set("vu", strconv.FormatUint(u.ID, 10))
 	}
 	if opts.SystemTags.Has(stats.TagIter) {
-		u.state.Tags["iter"] = strconv.FormatInt(u.iteration, 10)
+		u.state.Tags.Set("iter", strconv.FormatInt(u.iteration, 10))
 	}
 	if opts.SystemTags.Has(stats.TagGroup) {
-		u.state.Tags["group"] = u.state.Group.Path
+		u.state.Tags.Set("group", u.state.Group.Path)
 	}
 	if opts.SystemTags.Has(stats.TagScenario) {
-		u.state.Tags["scenario"] = params.Scenario
+		u.state.Tags.Set("scenario", params.Scenario)
 	}
 
 	ctx := common.WithRuntime(params.RunContext, u.Runtime)
@@ -691,11 +727,20 @@ func (u *ActiveVU) RunOnce() error {
 
 	// Call the exported function.
 	_, isFullIteration, totalTime, err := u.runFn(u.RunContext, true, fn, u.setupData)
+	if err != nil {
+		var x *goja.InterruptedError
+		if errors.As(err, &x) {
+			if v, ok := x.Value().(*common.InterruptError); ok {
+				v.Reason = x.Error()
+				err = v
+			}
+		}
+	}
 
 	// If MinIterationDuration is specified and the iteration wasn't canceled
 	// and was less than it, sleep for the remainder
 	if isFullIteration && u.Runner.Bundle.Options.MinIterationDuration.Valid {
-		durationDiff := time.Duration(u.Runner.Bundle.Options.MinIterationDuration.Duration) - totalTime
+		durationDiff := u.Runner.Bundle.Options.MinIterationDuration.TimeDuration() - totalTime
 		if durationDiff > 0 {
 			select {
 			case <-time.After(durationDiff):
@@ -719,7 +764,7 @@ func (u *VU) runFn(
 
 	opts := &u.Runner.Bundle.Options
 	if opts.SystemTags.Has(stats.TagIter) {
-		u.state.Tags["iter"] = strconv.FormatInt(u.state.Iteration, 10)
+		u.state.Tags.Set("iter", strconv.FormatInt(u.state.Iteration, 10))
 	}
 
 	defer func() {
@@ -757,7 +802,9 @@ func (u *VU) runFn(
 		u.Transport.CloseIdleConnections()
 	}
 
-	u.state.Samples <- u.Dialer.GetTrail(startTime, endTime, isFullIteration, isDefault, stats.NewSampleTags(u.state.Tags))
+	sampleTags := stats.NewSampleTags(u.state.CloneTags())
+	u.state.Samples <- u.Dialer.GetTrail(
+		startTime, endTime, isFullIteration, isDefault, sampleTags, u.Runner.builtinMetrics)
 
 	return v, isFullIteration, endTime.Sub(startTime), err
 }
