@@ -51,6 +51,45 @@ var (
 		"Array.prototype.item",        // not even standard yet
 		"TypedArray.prototype.item",   // not even standard yet
 		"String.prototype.replaceAll", // not supported at all, Stage 4 since 2020
+
+		// from goja
+		"Symbol.asyncIterator",
+		"async-functions",
+		"class-static-block",
+		"class-fields-private",
+		"class-fields-private-in",
+		"regexp-named-groups",
+		"regexp-dotall",
+		"regexp-unicode-property-escapes",
+		"regexp-unicode-property-escapes",
+		"regexp-match-indices",
+		"legacy-regexp",
+		"tail-call-optimization",
+		"Temporal",
+		"import-assertions",
+		"dynamic-import",
+		"logical-assignment-operators",
+		"coalesce-expression",
+		"import.meta",
+		"optional-chaining",
+		"Atomics",
+		"Atomics.waitAsync",
+		"FinalizationRegistry",
+		"WeakRef",
+		"numeric-separator-literal",
+		"Object.fromEntries",
+		"Object.hasOwn",
+		"__getter__",
+		"__setter__",
+		"ShadowRealm",
+		"SharedArrayBuffer",
+		"error-cause",
+		"resizable-arraybuffer", // stage 3 as of 2021 https://github.com/tc39/proposal-resizablearraybuffer
+
+		"array-find-from-last",    // stage 3 as of 2021 https://github.com/tc39/proposal-array-find-from-last
+		"Array.prototype.at",      // stage 3 as of 2021 https://github.com/tc39/proposal-relative-indexing-method
+		"String.prototype.at",     // stage 3 as of 2021 https://github.com/tc39/proposal-relative-indexing-method
+		"TypedArray.prototype.at", // stage 3 as of 2021 https://github.com/tc39/proposal-relative-indexing-method
 	}
 	skipWords = []string{"async", "yield", "generator", "Generator"}
 	skipList  = map[string]bool{
@@ -93,9 +132,7 @@ var (
 		"test/built-ins/AsyncIteratorPrototype",
 		"test/built-ins/Atomics",
 		"test/built-ins/BigInt",
-		"test/built-ins/Promise",
 		"test/built-ins/SharedArrayBuffer",
-		"test/built-ins/NativeErrors/AggregateError",
 		"test/language/eval-code/direct/async",
 		"test/language/expressions/async",
 		"test/language/expressions/dynamic-import",
@@ -438,9 +475,10 @@ func (ctx *tc39TestCtx) compile(base, name string) (*goja.Program, error) {
 		}
 
 		str := string(b)
-		compiler := ctx.compilerPool.Get()
-		defer ctx.compilerPool.Put(compiler)
-		prg, _, err = compiler.Compile(str, name, "", "", false, lib.CompatibilityModeExtended)
+		comp := ctx.compilerPool.Get()
+		defer ctx.compilerPool.Put(comp)
+		comp.Options = compiler.Options{Strict: false, CompatibilityMode: lib.CompatibilityModeExtended}
+		prg, _, err = comp.Compile(str, name, true)
 		if err != nil {
 			return nil, err
 		}
@@ -479,13 +517,14 @@ func (ctx *tc39TestCtx) runTC39Script(name, src string, includes []string, vm *g
 	}
 
 	var p *goja.Program
-	compiler := ctx.compilerPool.Get()
-	defer ctx.compilerPool.Put(compiler)
-	p, _, origErr = compiler.Compile(src, name, "", "", false, lib.CompatibilityModeBase)
+	comp := ctx.compilerPool.Get()
+	defer ctx.compilerPool.Put(comp)
+	comp.Options = compiler.Options{Strict: false, CompatibilityMode: lib.CompatibilityModeBase}
+	p, _, origErr = comp.Compile(src, name, true)
 	if origErr != nil {
-		src, _, err = compiler.Transform(src, name)
+		src, _, err = comp.Transform(src, name, nil)
 		if err == nil {
-			p, _, err = compiler.Compile(src, name, "", "", false, lib.CompatibilityModeBase)
+			p, _, err = comp.Compile(src, name, true)
 		}
 	} else {
 		err = origErr
