@@ -30,6 +30,7 @@ import (
 	"gopkg.in/guregu/null.v3"
 
 	"go.k6.io/k6/lib"
+	"go.k6.io/k6/lib/metrics"
 	"go.k6.io/k6/lib/types"
 	"go.k6.io/k6/stats"
 	"go.k6.io/k6/ui/pb"
@@ -90,7 +91,7 @@ func (clvc ConstantVUsConfig) Validate() []error {
 
 	if !clvc.Duration.Valid {
 		errors = append(errors, fmt.Errorf("the duration is unspecified"))
-	} else if time.Duration(clvc.Duration.Duration) < minDuration {
+	} else if clvc.Duration.TimeDuration() < minDuration {
 		errors = append(errors, fmt.Errorf(
 			"the duration should be at least %s, but is %s", minDuration, clvc.Duration,
 		))
@@ -111,7 +112,7 @@ func (clvc ConstantVUsConfig) GetExecutionRequirements(et *lib.ExecutionTuple) [
 			PlannedVUs: uint64(clvc.GetVUs(et)),
 		},
 		{
-			TimeOffset: time.Duration(clvc.Duration.Duration + clvc.GracefulStop.Duration),
+			TimeOffset: clvc.Duration.TimeDuration() + clvc.GracefulStop.TimeDuration(),
 			PlannedVUs: 0,
 		},
 	}
@@ -142,9 +143,11 @@ var _ lib.Executor = &ConstantVUs{}
 
 // Run constantly loops through as many iterations as possible on a fixed number
 // of VUs for the specified duration.
-func (clv ConstantVUs) Run(parentCtx context.Context, out chan<- stats.SampleContainer) (err error) {
+func (clv ConstantVUs) Run(
+	parentCtx context.Context, out chan<- stats.SampleContainer, _ *metrics.BuiltinMetrics,
+) (err error) {
 	numVUs := clv.config.GetVUs(clv.executionState.ExecutionTuple)
-	duration := time.Duration(clv.config.Duration.Duration)
+	duration := clv.config.Duration.TimeDuration()
 	gracefulStop := clv.config.GetGracefulStop()
 
 	startTime, maxDurationCtx, regDurationCtx, cancel := getDurationContexts(parentCtx, duration, gracefulStop)
