@@ -79,7 +79,9 @@ func TestRampingArrivalRateRunNotEnoughAllocatedVUsWarn(t *testing.T) {
 	)
 	defer cancel()
 	engineOut := make(chan stats.SampleContainer, 1000)
-	err = executor.Run(ctx, engineOut)
+	registry := metrics.NewRegistry()
+	builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
+	err = executor.Run(ctx, engineOut, builtinMetrics)
 	require.NoError(t, err)
 	entries := logHook.Drain()
 	require.NotEmpty(t, entries)
@@ -125,7 +127,9 @@ func TestRampingArrivalRateRunCorrectRate(t *testing.T) {
 		assert.InDelta(t, 50, currentCount, 3)
 	}()
 	engineOut := make(chan stats.SampleContainer, 1000)
-	err = executor.Run(ctx, engineOut)
+	registry := metrics.NewRegistry()
+	builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
+	err = executor.Run(ctx, engineOut, builtinMetrics)
 	wg.Wait()
 	require.NoError(t, err)
 	require.Empty(t, logHook.Drain())
@@ -188,11 +192,13 @@ func TestRampingArrivalRateRunUnplannedVUs(t *testing.T) {
 		idl, idg := es.GetUniqueVUIdentifiers()
 		return runner.NewVU(idl, idg, engineOut)
 	})
-	err = executor.Run(ctx, engineOut)
+	registry := metrics.NewRegistry()
+	builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
+	err = executor.Run(ctx, engineOut, builtinMetrics)
 	assert.NoError(t, err)
 	assert.Empty(t, logHook.Drain())
 
-	droppedIters := sumMetricValues(engineOut, metrics.DroppedIterations.Name)
+	droppedIters := sumMetricValues(engineOut, metrics.DroppedIterationsName)
 	assert.Equal(t, count+int64(droppedIters), int64(9))
 }
 
@@ -239,7 +245,9 @@ func TestRampingArrivalRateRunCorrectRateWithSlowRate(t *testing.T) {
 		idl, idg := es.GetUniqueVUIdentifiers()
 		return runner.NewVU(idl, idg, engineOut)
 	})
-	err = executor.Run(ctx, engineOut)
+	registry := metrics.NewRegistry()
+	builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
+	err = executor.Run(ctx, engineOut, builtinMetrics)
 	assert.NoError(t, err)
 	assert.Empty(t, logHook.Drain())
 	assert.Equal(t, int64(0), es.GetCurrentlyActiveVUsCount())
@@ -278,7 +286,9 @@ func TestRampingArrivalRateRunGracefulStop(t *testing.T) {
 	engineOut := make(chan stats.SampleContainer, 1000)
 	defer close(engineOut)
 
-	err = executor.Run(ctx, engineOut)
+	registry := metrics.NewRegistry()
+	builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
+	err = executor.Run(ctx, engineOut, builtinMetrics)
 	assert.NoError(t, err)
 	assert.Equal(t, int64(0), es.GetCurrentlyActiveVUsCount())
 	assert.Equal(t, int64(10), es.GetInitializedVUsCount())
@@ -338,7 +348,9 @@ func BenchmarkRampingArrivalRateRun(b *testing.B) {
 			b.ResetTimer()
 			start := time.Now()
 
-			err := executor.Run(ctx, engineOut)
+			registry := metrics.NewRegistry()
+			builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
+			err := executor.Run(ctx, engineOut, builtinMetrics)
 			took := time.Since(start)
 			assert.NoError(b, err)
 
@@ -644,7 +656,7 @@ func (varc RampingArrivalRateConfig) calRat(et *lib.ExecutionTuple, ch chan<- ti
 			var (
 				from = big.NewRat(curr, int64(time.Second))
 				to   = big.NewRat(target, int64(time.Second))
-				dur  = big.NewRat(time.Duration(stage.Duration.Duration).Nanoseconds(), 1)
+				dur  = big.NewRat(stage.Duration.TimeDuration().Nanoseconds(), 1)
 			)
 			// precalcualations :)
 			toMinusFrom := new(big.Rat).Sub(to, from)
@@ -675,7 +687,7 @@ func (varc RampingArrivalRateConfig) calRat(et *lib.ExecutionTuple, ch chan<- ti
 			step := big.NewRat(int64(time.Second), target)
 			first := big.NewRat(0, 1)
 			first.Sub(first, carry)
-			endCount.Add(endCount, new(big.Rat).Mul(big.NewRat(target, 1), big.NewRat(time.Duration(stage.Duration.Duration).Nanoseconds(), time.Duration(varc.TimeUnit.Duration).Nanoseconds())))
+			endCount.Add(endCount, new(big.Rat).Mul(big.NewRat(target, 1), big.NewRat(stage.Duration.TimeDuration().Nanoseconds(), varc.TimeUnit.TimeDuration().Nanoseconds())))
 
 			for ; endCount.Cmp(iRat) >= 0; iRat.Add(iRat, big.NewRat(next(), 1)) {
 				res := new(big.Rat).Sub(iRat, doneSoFar) // this can get next added to it but will need to change the above for .. so
@@ -686,7 +698,7 @@ func (varc RampingArrivalRateConfig) calRat(et *lib.ExecutionTuple, ch chan<- ti
 		}
 		doneSoFar.Set(endCount) // copy
 		curr = target
-		base += time.Duration(stage.Duration.Duration)
+		base += stage.Duration.TimeDuration()
 	}
 }
 
@@ -747,7 +759,9 @@ func TestRampingArrivalRateGlobalIters(t *testing.T) {
 			}
 
 			engineOut := make(chan stats.SampleContainer, 100)
-			err = executor.Run(ctx, engineOut)
+			registry := metrics.NewRegistry()
+			builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
+			err = executor.Run(ctx, engineOut, builtinMetrics)
 			require.NoError(t, err)
 			assert.Equal(t, tc.expIters, gotIters)
 		})
