@@ -63,7 +63,9 @@ func TestSharedIterationsRun(t *testing.T) {
 		}),
 	)
 	defer cancel()
-	err = executor.Run(ctx, nil)
+	registry := metrics.NewRegistry()
+	builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
+	err = executor.Run(ctx, nil, builtinMetrics)
 	require.NoError(t, err)
 	assert.Equal(t, uint64(100), doneIters)
 }
@@ -79,7 +81,7 @@ func TestSharedIterationsRunVariableVU(t *testing.T) {
 	et, err := lib.NewExecutionTuple(nil, nil)
 	require.NoError(t, err)
 	es := lib.NewExecutionState(lib.Options{}, et, 10, 50)
-	var ctx, cancel, executor, _ = setupExecutor(
+	ctx, cancel, executor, _ := setupExecutor(
 		t, getTestSharedIterationsConfig(), es,
 		simpleRunner(func(ctx context.Context) error {
 			time.Sleep(10 * time.Millisecond) // small wait to stabilize the test
@@ -98,7 +100,9 @@ func TestSharedIterationsRunVariableVU(t *testing.T) {
 		}),
 	)
 	defer cancel()
-	err = executor.Run(ctx, nil)
+	registry := metrics.NewRegistry()
+	builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
+	err = executor.Run(ctx, nil, builtinMetrics)
 	require.NoError(t, err)
 
 	var totalIters uint64
@@ -138,11 +142,13 @@ func TestSharedIterationsEmitDroppedIterations(t *testing.T) {
 	)
 	defer cancel()
 	engineOut := make(chan stats.SampleContainer, 1000)
-	err = executor.Run(ctx, engineOut)
+	registry := metrics.NewRegistry()
+	builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
+	err = executor.Run(ctx, engineOut, builtinMetrics)
 	require.NoError(t, err)
 	assert.Empty(t, logHook.Drain())
 	assert.Equal(t, int64(5), count)
-	assert.Equal(t, float64(95), sumMetricValues(engineOut, metrics.DroppedIterations.Name))
+	assert.Equal(t, float64(95), sumMetricValues(engineOut, metrics.DroppedIterationsName))
 }
 
 func TestSharedIterationsGlobalIters(t *testing.T) {
@@ -190,7 +196,9 @@ func TestSharedIterationsGlobalIters(t *testing.T) {
 			}
 
 			engineOut := make(chan stats.SampleContainer, 100)
-			err = executor.Run(ctx, engineOut)
+			registry := metrics.NewRegistry()
+			builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
+			err = executor.Run(ctx, engineOut, builtinMetrics)
 			require.NoError(t, err)
 			sort.Slice(gotIters, func(i, j int) bool { return gotIters[i] < gotIters[j] })
 			assert.Equal(t, tc.expIters, gotIters)
