@@ -118,7 +118,13 @@ func TestMakeRequestError(t *testing.T) {
 			Body:         new(bytes.Buffer),
 			Compressions: []CompressionType{badCompressionType},
 		}
-		_, err = MakeRequest(ctx, preq)
+		state := &lib.State{
+			Options:   lib.Options{RunTags: &stats.SampleTags{}},
+			Transport: http.DefaultTransport,
+			Logger:    logrus.New(),
+			Tags:      lib.NewTagMap(nil),
+		}
+		_, err = MakeRequest(ctx, state, preq)
 		require.Error(t, err)
 		require.Equal(t, err.Error(), "unknown compressionType CompressionType(13)")
 	})
@@ -139,8 +145,8 @@ func TestMakeRequestError(t *testing.T) {
 			Options:   lib.Options{RunTags: &stats.SampleTags{}},
 			Transport: srv.Client().Transport,
 			Logger:    logger,
+			Tags:      lib.NewTagMap(nil),
 		}
-		ctx = lib.WithState(ctx, state)
 		req, _ := http.NewRequest("GET", srv.URL, nil)
 		preq := &ParsedHTTPRequest{
 			Req:     req,
@@ -149,7 +155,7 @@ func TestMakeRequestError(t *testing.T) {
 			Timeout: 10 * time.Second,
 		}
 
-		res, err := MakeRequest(ctx, preq)
+		res, err := MakeRequest(ctx, state, preq)
 
 		assert.Nil(t, res)
 		assert.EqualError(t, err, "unsupported response status: 101 Switching Protocols")
@@ -184,13 +190,16 @@ func TestResponseStatus(t *testing.T) {
 				defer server.Close()
 				logger := logrus.New()
 				logger.Level = logrus.DebugLevel
+				samples := make(chan<- stats.SampleContainer, 1)
+				registry := metrics.NewRegistry()
 				state := &lib.State{
-					Options:   lib.Options{RunTags: &stats.SampleTags{}},
-					Transport: server.Client().Transport,
-					Logger:    logger,
-					Samples:   make(chan<- stats.SampleContainer, 1),
+					Options:        lib.Options{RunTags: &stats.SampleTags{}},
+					Transport:      server.Client().Transport,
+					Logger:         logger,
+					Samples:        samples,
+					BuiltinMetrics: metrics.RegisterBuiltinMetrics(registry),
+					Tags:           lib.NewTagMap(nil),
 				}
-				ctx := lib.WithState(context.Background(), state)
 				req, err := http.NewRequest("GET", server.URL, nil)
 				require.NoError(t, err)
 
@@ -202,7 +211,9 @@ func TestResponseStatus(t *testing.T) {
 					ResponseType: ResponseTypeNone,
 				}
 
-				res, err := MakeRequest(ctx, preq)
+				ctx, cancel := context.WithCancel(context.Background())
+				defer cancel()
+				res, err := MakeRequest(ctx, state, preq)
 				require.NoError(t, err)
 				assert.Equal(t, tc.statusCodeExpected, res.Status)
 				assert.Equal(t, tc.statusCodeStringExpected, res.StatusText)
@@ -258,17 +269,19 @@ func TestMakeRequestTimeoutInTheMiddle(t *testing.T) {
 	samples := make(chan stats.SampleContainer, 10)
 	logger := logrus.New()
 	logger.Level = logrus.DebugLevel
+	registry := metrics.NewRegistry()
 	state := &lib.State{
 		Options: lib.Options{
 			RunTags:    &stats.SampleTags{},
 			SystemTags: &stats.DefaultSystemTagSet,
 		},
-		Transport: srv.Client().Transport,
-		Samples:   samples,
-		Logger:    logger,
-		BPool:     bpool.NewBufferPool(100),
+		Transport:      srv.Client().Transport,
+		Samples:        samples,
+		Logger:         logger,
+		BPool:          bpool.NewBufferPool(100),
+		BuiltinMetrics: metrics.RegisterBuiltinMetrics(registry),
+		Tags:           lib.NewTagMap(nil),
 	}
-	ctx = lib.WithState(ctx, state)
 	req, _ := http.NewRequest("GET", srv.URL, nil)
 	preq := &ParsedHTTPRequest{
 		Req:              req,
@@ -278,7 +291,7 @@ func TestMakeRequestTimeoutInTheMiddle(t *testing.T) {
 		ResponseCallback: func(i int) bool { return i == 0 },
 	}
 
-	res, err := MakeRequest(ctx, preq)
+	res, err := MakeRequest(ctx, state, preq)
 	require.NoError(t, err)
 	assert.NotNil(t, res)
 	assert.Len(t, samples, 1)
@@ -333,17 +346,19 @@ func TestTrailFailed(t *testing.T) {
 			samples := make(chan stats.SampleContainer, 10)
 			logger := logrus.New()
 			logger.Level = logrus.DebugLevel
+			registry := metrics.NewRegistry()
 			state := &lib.State{
 				Options: lib.Options{
 					RunTags:    &stats.SampleTags{},
 					SystemTags: &stats.DefaultSystemTagSet,
 				},
-				Transport: srv.Client().Transport,
-				Samples:   samples,
-				Logger:    logger,
-				BPool:     bpool.NewBufferPool(2),
+				Transport:      srv.Client().Transport,
+				Samples:        samples,
+				Logger:         logger,
+				BPool:          bpool.NewBufferPool(2),
+				BuiltinMetrics: metrics.RegisterBuiltinMetrics(registry),
+				Tags:           lib.NewTagMap(nil),
 			}
-			ctx = lib.WithState(ctx, state)
 			req, _ := http.NewRequest("GET", srv.URL, nil)
 			preq := &ParsedHTTPRequest{
 				Req:              req,
@@ -352,7 +367,7 @@ func TestTrailFailed(t *testing.T) {
 				Timeout:          10 * time.Millisecond,
 				ResponseCallback: responseCallback,
 			}
-			res, err := MakeRequest(ctx, preq)
+			res, err := MakeRequest(ctx, state, preq)
 
 			require.NoError(t, err)
 			require.NotNil(t, res)
@@ -363,7 +378,7 @@ func TestTrailFailed(t *testing.T) {
 
 			var httpReqFailedSampleValue null.Bool
 			for _, s := range sample.GetSamples() {
-				if s.Metric.Name == metrics.HTTPReqFailed.Name {
+				if s.Metric.Name == metrics.HTTPReqFailedName {
 					httpReqFailedSampleValue.Valid = true
 					if s.Value == 1.0 {
 						httpReqFailedSampleValue.Bool = true
@@ -393,6 +408,7 @@ func TestMakeRequestDialTimeout(t *testing.T) {
 	samples := make(chan stats.SampleContainer, 10)
 	logger := logrus.New()
 	logger.Level = logrus.DebugLevel
+	registry := metrics.NewRegistry()
 	state := &lib.State{
 		Options: lib.Options{
 			RunTags:    &stats.SampleTags{},
@@ -403,12 +419,13 @@ func TestMakeRequestDialTimeout(t *testing.T) {
 				Timeout: 1 * time.Microsecond,
 			}).DialContext,
 		},
-		Samples: samples,
-		Logger:  logger,
-		BPool:   bpool.NewBufferPool(100),
+		Samples:        samples,
+		Logger:         logger,
+		BPool:          bpool.NewBufferPool(100),
+		BuiltinMetrics: metrics.RegisterBuiltinMetrics(registry),
+		Tags:           lib.NewTagMap(nil),
 	}
 
-	ctx = lib.WithState(ctx, state)
 	req, _ := http.NewRequest("GET", "http://"+addr.String(), nil)
 	preq := &ParsedHTTPRequest{
 		Req:              req,
@@ -418,7 +435,7 @@ func TestMakeRequestDialTimeout(t *testing.T) {
 		ResponseCallback: func(i int) bool { return i == 0 },
 	}
 
-	res, err := MakeRequest(ctx, preq)
+	res, err := MakeRequest(ctx, state, preq)
 	require.NoError(t, err)
 	assert.NotNil(t, res)
 	assert.Len(t, samples, 1)
@@ -450,17 +467,19 @@ func TestMakeRequestTimeoutInTheBegining(t *testing.T) {
 	samples := make(chan stats.SampleContainer, 10)
 	logger := logrus.New()
 	logger.Level = logrus.DebugLevel
+	registry := metrics.NewRegistry()
 	state := &lib.State{
 		Options: lib.Options{
 			RunTags:    &stats.SampleTags{},
 			SystemTags: &stats.DefaultSystemTagSet,
 		},
-		Transport: srv.Client().Transport,
-		Samples:   samples,
-		Logger:    logger,
-		BPool:     bpool.NewBufferPool(100),
+		Transport:      srv.Client().Transport,
+		Samples:        samples,
+		Logger:         logger,
+		BPool:          bpool.NewBufferPool(100),
+		BuiltinMetrics: metrics.RegisterBuiltinMetrics(registry),
+		Tags:           lib.NewTagMap(nil),
 	}
-	ctx = lib.WithState(ctx, state)
 	req, _ := http.NewRequest("GET", srv.URL, nil)
 	preq := &ParsedHTTPRequest{
 		Req:              req,
@@ -470,7 +489,7 @@ func TestMakeRequestTimeoutInTheBegining(t *testing.T) {
 		ResponseCallback: func(i int) bool { return i == 0 },
 	}
 
-	res, err := MakeRequest(ctx, preq)
+	res, err := MakeRequest(ctx, state, preq)
 	require.NoError(t, err)
 	assert.NotNil(t, res)
 	assert.Len(t, samples, 1)
