@@ -297,9 +297,9 @@ type Options struct {
 	ExecutionSegmentSequence *ExecutionSegmentSequence `json:"executionSegmentSequence" ignored:"true"`
 
 	// Timeouts for the setup() and teardown() functions
-	NoSetup         null.Bool          `json:"noSetup" envconfig:"NO_SETUP"`
+	NoSetup         null.Bool          `json:"noSetup" envconfig:"K6_NO_SETUP"`
 	SetupTimeout    types.NullDuration `json:"setupTimeout" envconfig:"K6_SETUP_TIMEOUT"`
-	NoTeardown      null.Bool          `json:"noTeardown" envconfig:"NO_TEARDOWN"`
+	NoTeardown      null.Bool          `json:"noTeardown" envconfig:"K6_NO_TEARDOWN"`
 	TeardownTimeout types.NullDuration `json:"teardownTimeout" envconfig:"K6_TEARDOWN_TIMEOUT"`
 
 	// Limit HTTP requests per second.
