@@ -67,9 +67,9 @@ func TestOptions(t *testing.T) {
 		}})
 		assert.NotNil(t, opts.Stages)
 		assert.Len(t, opts.Stages, 2)
-		assert.Equal(t, 1*time.Second, time.Duration(opts.Stages[0].Duration.Duration))
+		assert.Equal(t, 1*time.Second, opts.Stages[0].Duration.TimeDuration())
 		assert.Equal(t, int64(10), opts.Stages[0].Target.Int64)
-		assert.Equal(t, 2*time.Second, time.Duration(opts.Stages[1].Duration.Duration))
+		assert.Equal(t, 2*time.Second, opts.Stages[1].Duration.TimeDuration())
 		assert.Equal(t, int64(20), opts.Stages[1].Target.Int64)
 
 		emptyStages := []Stage{}
@@ -475,6 +475,16 @@ func TestOptionsEnv(t *testing.T) {
 			"":    null.Int{},
 			"123": null.IntFrom(123),
 		},
+		{"NoSetup", "K6_NO_SETUP"}: {
+			"":      null.Bool{},
+			"true":  null.BoolFrom(true),
+			"false": null.BoolFrom(false),
+		},
+		{"NoTeardown", "K6_NO_TEARDOWN"}: {
+			"":      null.Bool{},
+			"true":  null.BoolFrom(true),
+			"false": null.BoolFrom(false),
+		},
 		{"InsecureSkipTLSVerify", "K6_INSECURE_SKIP_TLS_VERIFY"}: {
 			"":      null.Bool{},
 			"true":  null.BoolFrom(true),
